/* GXmlNode.c generated by valac 0.34.6, the Vala compiler
 * generated from GXmlNode.vala, do not modify */

/* -*- Mode: vala; indent-tabs-mode: nil; c-basic-offset: 0; tab-width: 2 -*- */
/* ObjectModel.vala
 *
 * Copyright (C) 2015  Daniel Espinosa <esodan@gmail.com>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.

 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, see <http://www.gnu.org/licenses/>.
 *
 * Authors:
 *      Daniel Espinosa <esodan@gmail.com>
 */

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gee.h>
#include <gio/gio.h>
#include <libxml/tree.h>
#include <libxml/xmlerror.h>
#include <glib/gi18n-lib.h>
#include <libxml/parser.h>


#define GXML_TYPE_DOM_EVENT_TARGET (gxml_dom_event_target_get_type ())
#define GXML_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTarget))
#define GXML_IS_DOM_EVENT_TARGET(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_TARGET))
#define GXML_DOM_EVENT_TARGET_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_TARGET, GXmlDomEventTargetIface))

typedef struct _GXmlDomEventTarget GXmlDomEventTarget;
typedef struct _GXmlDomEventTargetIface GXmlDomEventTargetIface;

#define GXML_TYPE_DOM_EVENT_LISTENER (gxml_dom_event_listener_get_type ())
#define GXML_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListener))
#define GXML_IS_DOM_EVENT_LISTENER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT_LISTENER))
#define GXML_DOM_EVENT_LISTENER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT_LISTENER, GXmlDomEventListenerIface))

typedef struct _GXmlDomEventListener GXmlDomEventListener;
typedef struct _GXmlDomEventListenerIface GXmlDomEventListenerIface;

#define GXML_TYPE_DOM_EVENT (gxml_dom_event_get_type ())
#define GXML_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEvent))
#define GXML_IS_DOM_EVENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_EVENT))
#define GXML_DOM_EVENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_EVENT, GXmlDomEventIface))

typedef struct _GXmlDomEvent GXmlDomEvent;
typedef struct _GXmlDomEventIface GXmlDomEventIface;

#define GXML_TYPE_DOM_TIME_STAMP (gxml_dom_time_stamp_get_type ())
#define GXML_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStamp))
#define GXML_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))
#define GXML_IS_DOM_TIME_STAMP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_IS_DOM_TIME_STAMP_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_TIME_STAMP))
#define GXML_DOM_TIME_STAMP_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_TIME_STAMP, GXmlDomTimeStampClass))

typedef struct _GXmlDomTimeStamp GXmlDomTimeStamp;
typedef struct _GXmlDomTimeStampClass GXmlDomTimeStampClass;

#define GXML_DOM_EVENT_TYPE_PHASE (gxml_dom_event_phase_get_type ())

#define GXML_TYPE_DOM_NODE (gxml_dom_node_get_type ())
#define GXML_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE, GXmlDomNode))
#define GXML_IS_DOM_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE))
#define GXML_DOM_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE, GXmlDomNodeIface))

typedef struct _GXmlDomNode GXmlDomNode;
typedef struct _GXmlDomNodeIface GXmlDomNodeIface;

#define GXML_DOM_NODE_TYPE_DOCUMENT_POSITION (gxml_dom_node_document_position_get_type ())

#define GXML_DOM_NODE_TYPE_NODE_TYPE (gxml_dom_node_node_type_get_type ())

#define GXML_TYPE_DOM_PARENT_NODE (gxml_dom_parent_node_get_type ())
#define GXML_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNode))
#define GXML_IS_DOM_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PARENT_NODE))
#define GXML_DOM_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PARENT_NODE, GXmlDomParentNodeIface))

typedef struct _GXmlDomParentNode GXmlDomParentNode;
typedef struct _GXmlDomParentNodeIface GXmlDomParentNodeIface;

#define GXML_TYPE_DOM_CHILD_NODE (gxml_dom_child_node_get_type ())
#define GXML_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNode))
#define GXML_IS_DOM_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHILD_NODE))
#define GXML_DOM_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHILD_NODE, GXmlDomChildNodeIface))

typedef struct _GXmlDomChildNode GXmlDomChildNode;
typedef struct _GXmlDomChildNodeIface GXmlDomChildNodeIface;

#define GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE (gxml_dom_non_document_type_child_node_get_type ())
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNode))
#define GXML_IS_DOM_NON_DOCUMENT_TYPE_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE))
#define GXML_DOM_NON_DOCUMENT_TYPE_CHILD_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_DOCUMENT_TYPE_CHILD_NODE, GXmlDomNonDocumentTypeChildNodeIface))

typedef struct _GXmlDomNonDocumentTypeChildNode GXmlDomNonDocumentTypeChildNode;
typedef struct _GXmlDomNonDocumentTypeChildNodeIface GXmlDomNonDocumentTypeChildNodeIface;

#define GXML_TYPE_DOM_ELEMENT (gxml_dom_element_get_type ())
#define GXML_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElement))
#define GXML_IS_DOM_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT))
#define GXML_DOM_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_ELEMENT, GXmlDomElementIface))

typedef struct _GXmlDomElement GXmlDomElement;
typedef struct _GXmlDomElementIface GXmlDomElementIface;

#define GXML_TYPE_DOM_HTML_COLLECTION (gxml_dom_html_collection_get_type ())
#define GXML_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollection))
#define GXML_IS_DOM_HTML_COLLECTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_HTML_COLLECTION))
#define GXML_DOM_HTML_COLLECTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_HTML_COLLECTION, GXmlDomHTMLCollectionIface))

typedef struct _GXmlDomHTMLCollection GXmlDomHTMLCollection;
typedef struct _GXmlDomHTMLCollectionIface GXmlDomHTMLCollectionIface;

#define GXML_TYPE_DOM_TOKEN_LIST (gxml_dom_token_list_get_type ())
#define GXML_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenList))
#define GXML_IS_DOM_TOKEN_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TOKEN_LIST))
#define GXML_DOM_TOKEN_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TOKEN_LIST, GXmlDomTokenListIface))

typedef struct _GXmlDomTokenList GXmlDomTokenList;
typedef struct _GXmlDomTokenListIface GXmlDomTokenListIface;

#define GXML_TYPE_DOM_NAMED_NODE_MAP (gxml_dom_named_node_map_get_type ())
#define GXML_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMap))
#define GXML_IS_DOM_NAMED_NODE_MAP(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP))
#define GXML_DOM_NAMED_NODE_MAP_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NAMED_NODE_MAP, GXmlDomNamedNodeMapIface))

typedef struct _GXmlDomNamedNodeMap GXmlDomNamedNodeMap;
typedef struct _GXmlDomNamedNodeMapIface GXmlDomNamedNodeMapIface;

#define GXML_TYPE_DOM_NODE_LIST (gxml_dom_node_list_get_type ())
#define GXML_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeList))
#define GXML_IS_DOM_NODE_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_LIST))
#define GXML_DOM_NODE_LIST_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_LIST, GXmlDomNodeListIface))

typedef struct _GXmlDomNodeList GXmlDomNodeList;
typedef struct _GXmlDomNodeListIface GXmlDomNodeListIface;

#define GXML_TYPE_DOM_ELEMENT_LIST (gxml_dom_element_list_get_type ())
#define GXML_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementList))
#define GXML_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))
#define GXML_IS_DOM_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_IS_DOM_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_ELEMENT_LIST))
#define GXML_DOM_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_ELEMENT_LIST, GXmlDomElementListClass))

typedef struct _GXmlDomElementList GXmlDomElementList;
typedef struct _GXmlDomElementListClass GXmlDomElementListClass;

#define GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE (gxml_dom_non_element_parent_node_get_type ())
#define GXML_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNode))
#define GXML_IS_DOM_NON_ELEMENT_PARENT_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE))
#define GXML_DOM_NON_ELEMENT_PARENT_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NON_ELEMENT_PARENT_NODE, GXmlDomNonElementParentNodeIface))

typedef struct _GXmlDomNonElementParentNode GXmlDomNonElementParentNode;
typedef struct _GXmlDomNonElementParentNodeIface GXmlDomNonElementParentNodeIface;

#define GXML_TYPE_DOM_DOCUMENT (gxml_dom_document_get_type ())
#define GXML_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocument))
#define GXML_IS_DOM_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT))
#define GXML_DOM_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT, GXmlDomDocumentIface))

typedef struct _GXmlDomDocument GXmlDomDocument;
typedef struct _GXmlDomDocumentIface GXmlDomDocumentIface;

#define GXML_TYPE_DOM_DOCUMENT_FRAGMENT (gxml_dom_document_fragment_get_type ())
#define GXML_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragment))
#define GXML_IS_DOM_DOCUMENT_FRAGMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT))
#define GXML_DOM_DOCUMENT_FRAGMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_FRAGMENT, GXmlDomDocumentFragmentIface))

typedef struct _GXmlDomDocumentFragment GXmlDomDocumentFragment;
typedef struct _GXmlDomDocumentFragmentIface GXmlDomDocumentFragmentIface;

#define GXML_TYPE_DOM_CHARACTER_DATA (gxml_dom_character_data_get_type ())
#define GXML_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterData))
#define GXML_IS_DOM_CHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_CHARACTER_DATA))
#define GXML_DOM_CHARACTER_DATA_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_CHARACTER_DATA, GXmlDomCharacterDataIface))

typedef struct _GXmlDomCharacterData GXmlDomCharacterData;
typedef struct _GXmlDomCharacterDataIface GXmlDomCharacterDataIface;

#define GXML_TYPE_DOM_TEXT (gxml_dom_text_get_type ())
#define GXML_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TEXT, GXmlDomText))
#define GXML_IS_DOM_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TEXT))
#define GXML_DOM_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TEXT, GXmlDomTextIface))

typedef struct _GXmlDomText GXmlDomText;
typedef struct _GXmlDomTextIface GXmlDomTextIface;

#define GXML_TYPE_DOM_COMMENT (gxml_dom_comment_get_type ())
#define GXML_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomComment))
#define GXML_IS_DOM_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_COMMENT))
#define GXML_DOM_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_COMMENT, GXmlDomCommentIface))

typedef struct _GXmlDomComment GXmlDomComment;
typedef struct _GXmlDomCommentIface GXmlDomCommentIface;

#define GXML_TYPE_DOM_PROCESSING_INSTRUCTION (gxml_dom_processing_instruction_get_type ())
#define GXML_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstruction))
#define GXML_IS_DOM_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION))
#define GXML_DOM_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_PROCESSING_INSTRUCTION, GXmlDomProcessingInstructionIface))

typedef struct _GXmlDomProcessingInstruction GXmlDomProcessingInstruction;
typedef struct _GXmlDomProcessingInstructionIface GXmlDomProcessingInstructionIface;

#define GXML_TYPE_DOM_RANGE (gxml_dom_range_get_type ())
#define GXML_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRange))
#define GXML_IS_DOM_RANGE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_RANGE))
#define GXML_DOM_RANGE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_RANGE, GXmlDomRangeIface))

typedef struct _GXmlDomRange GXmlDomRange;
typedef struct _GXmlDomRangeIface GXmlDomRangeIface;

#define GXML_DOM_RANGE_TYPE_BOUNDARY_POINTS (gxml_dom_range_boundary_points_get_type ())

#define GXML_TYPE_DOM_NODE_FILTER (gxml_dom_node_filter_get_type ())
#define GXML_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilter))
#define GXML_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))
#define GXML_IS_DOM_NODE_FILTER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_IS_DOM_NODE_FILTER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_DOM_NODE_FILTER))
#define GXML_DOM_NODE_FILTER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_DOM_NODE_FILTER, GXmlDomNodeFilterClass))

typedef struct _GXmlDomNodeFilter GXmlDomNodeFilter;
typedef struct _GXmlDomNodeFilterClass GXmlDomNodeFilterClass;

#define GXML_TYPE_DOM_NODE_ITERATOR (gxml_dom_node_iterator_get_type ())
#define GXML_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIterator))
#define GXML_IS_DOM_NODE_ITERATOR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_NODE_ITERATOR))
#define GXML_DOM_NODE_ITERATOR_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_NODE_ITERATOR, GXmlDomNodeIteratorIface))

typedef struct _GXmlDomNodeIterator GXmlDomNodeIterator;
typedef struct _GXmlDomNodeIteratorIface GXmlDomNodeIteratorIface;

#define GXML_TYPE_DOM_TREE_WALKER (gxml_dom_tree_walker_get_type ())
#define GXML_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalker))
#define GXML_IS_DOM_TREE_WALKER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_TREE_WALKER))
#define GXML_DOM_TREE_WALKER_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_TREE_WALKER, GXmlDomTreeWalkerIface))

typedef struct _GXmlDomTreeWalker GXmlDomTreeWalker;
typedef struct _GXmlDomTreeWalkerIface GXmlDomTreeWalkerIface;

#define GXML_TYPE_DOM_IMPLEMENTATION (gxml_dom_implementation_get_type ())
#define GXML_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementation))
#define GXML_IS_DOM_IMPLEMENTATION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_IMPLEMENTATION))
#define GXML_DOM_IMPLEMENTATION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_IMPLEMENTATION, GXmlDomImplementationIface))

typedef struct _GXmlDomImplementation GXmlDomImplementation;
typedef struct _GXmlDomImplementationIface GXmlDomImplementationIface;

#define GXML_TYPE_DOM_DOCUMENT_TYPE (gxml_dom_document_type_get_type ())
#define GXML_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentType))
#define GXML_IS_DOM_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE))
#define GXML_DOM_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_DOCUMENT_TYPE, GXmlDomDocumentTypeIface))

typedef struct _GXmlDomDocumentType GXmlDomDocumentType;
typedef struct _GXmlDomDocumentTypeIface GXmlDomDocumentTypeIface;

#define GXML_TYPE_DOM_XML_DOCUMENT (gxml_dom_xml_document_get_type ())
#define GXML_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocument))
#define GXML_IS_DOM_XML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOM_XML_DOCUMENT))
#define GXML_DOM_XML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOM_XML_DOCUMENT, GXmlDomXMLDocumentIface))

typedef struct _GXmlDomXMLDocument GXmlDomXMLDocument;
typedef struct _GXmlDomXMLDocumentIface GXmlDomXMLDocumentIface;

#define GXML_TYPE_NODE (gxml_node_get_type ())
#define GXML_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NODE, GXmlNode))
#define GXML_IS_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NODE))
#define GXML_NODE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NODE, GXmlNodeIface))

typedef struct _GXmlNode GXmlNode;
typedef struct _GXmlNodeIface GXmlNodeIface;

#define GXML_TYPE_ELEMENT_LIST (gxml_element_list_get_type ())
#define GXML_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementList))
#define GXML_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))
#define GXML_IS_ELEMENT_LIST(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT_LIST))
#define GXML_IS_ELEMENT_LIST_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_ELEMENT_LIST))
#define GXML_ELEMENT_LIST_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_ELEMENT_LIST, GXmlElementListClass))

typedef struct _GXmlElementList GXmlElementList;
typedef struct _GXmlElementListClass GXmlElementListClass;

#define GXML_TYPE_NAMESPACE (gxml_namespace_get_type ())
#define GXML_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_NAMESPACE, GXmlNamespace))
#define GXML_IS_NAMESPACE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_NAMESPACE))
#define GXML_NAMESPACE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_NAMESPACE, GXmlNamespaceIface))

typedef struct _GXmlNamespace GXmlNamespace;
typedef struct _GXmlNamespaceIface GXmlNamespaceIface;

#define GXML_TYPE_NODE_TYPE (gxml_node_type_get_type ())

#define GXML_TYPE_DOCUMENT (gxml_document_get_type ())
#define GXML_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT, GXmlDocument))
#define GXML_IS_DOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT))
#define GXML_DOCUMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT, GXmlDocumentIface))

typedef struct _GXmlDocument GXmlDocument;
typedef struct _GXmlDocumentIface GXmlDocumentIface;

#define GXML_TYPE_GNODE (gxml_gnode_get_type ())
#define GXML_GNODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNODE, GXmlGNode))
#define GXML_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNODE, GXmlGNodeClass))
#define GXML_IS_GNODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNODE))
#define GXML_IS_GNODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNODE))
#define GXML_GNODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNODE, GXmlGNodeClass))

typedef struct _GXmlGNode GXmlGNode;
typedef struct _GXmlGNodeClass GXmlGNodeClass;
typedef struct _GXmlGNodePrivate GXmlGNodePrivate;

#define GXML_TYPE_GDOCUMENT (gxml_gdocument_get_type ())
#define GXML_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocument))
#define GXML_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))
#define GXML_IS_GDOCUMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GDOCUMENT))
#define GXML_IS_GDOCUMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GDOCUMENT))
#define GXML_GDOCUMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GDOCUMENT, GXmlGDocumentClass))

typedef struct _GXmlGDocument GXmlGDocument;
typedef struct _GXmlGDocumentClass GXmlGDocumentClass;
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_regex_unref0(var) ((var == NULL) ? NULL : (var = (g_regex_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))

#define GXML_TYPE_GCHILD_NODE (gxml_gchild_node_get_type ())
#define GXML_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNode))
#define GXML_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))
#define GXML_IS_GCHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCHILD_NODE))
#define GXML_IS_GCHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCHILD_NODE))
#define GXML_GCHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCHILD_NODE, GXmlGChildNodeClass))

typedef struct _GXmlGChildNode GXmlGChildNode;
typedef struct _GXmlGChildNodeClass GXmlGChildNodeClass;

#define GXML_TYPE_GNON_DOCUMENT_CHILD_NODE (gxml_gnon_document_child_node_get_type ())
#define GXML_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNode))
#define GXML_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_IS_GNON_DOCUMENT_CHILD_NODE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE))
#define GXML_GNON_DOCUMENT_CHILD_NODE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GNON_DOCUMENT_CHILD_NODE, GXmlGNonDocumentChildNodeClass))

typedef struct _GXmlGNonDocumentChildNode GXmlGNonDocumentChildNode;
typedef struct _GXmlGNonDocumentChildNodeClass GXmlGNonDocumentChildNodeClass;

#define GXML_TYPE_GELEMENT (gxml_gelement_get_type ())
#define GXML_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GELEMENT, GXmlGElement))
#define GXML_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GELEMENT, GXmlGElementClass))
#define GXML_IS_GELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GELEMENT))
#define GXML_IS_GELEMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GELEMENT))
#define GXML_GELEMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GELEMENT, GXmlGElementClass))

typedef struct _GXmlGElement GXmlGElement;
typedef struct _GXmlGElementClass GXmlGElementClass;

#define GXML_TYPE_GATTRIBUTE (gxml_gattribute_get_type ())
#define GXML_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttribute))
#define GXML_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))
#define GXML_IS_GATTRIBUTE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GATTRIBUTE))
#define GXML_IS_GATTRIBUTE_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GATTRIBUTE))
#define GXML_GATTRIBUTE_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GATTRIBUTE, GXmlGAttributeClass))

typedef struct _GXmlGAttribute GXmlGAttribute;
typedef struct _GXmlGAttributeClass GXmlGAttributeClass;

#define GXML_TYPE_GCHARACTER_DATA (gxml_gcharacter_data_get_type ())
#define GXML_GCHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterData))
#define GXML_GCHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterDataClass))
#define GXML_IS_GCHARACTER_DATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCHARACTER_DATA))
#define GXML_IS_GCHARACTER_DATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCHARACTER_DATA))
#define GXML_GCHARACTER_DATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCHARACTER_DATA, GXmlGCharacterDataClass))

typedef struct _GXmlGCharacterData GXmlGCharacterData;
typedef struct _GXmlGCharacterDataClass GXmlGCharacterDataClass;

#define GXML_TYPE_GTEXT (gxml_gtext_get_type ())
#define GXML_GTEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GTEXT, GXmlGText))
#define GXML_GTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GTEXT, GXmlGTextClass))
#define GXML_IS_GTEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GTEXT))
#define GXML_IS_GTEXT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GTEXT))
#define GXML_GTEXT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GTEXT, GXmlGTextClass))

typedef struct _GXmlGText GXmlGText;
typedef struct _GXmlGTextClass GXmlGTextClass;

#define GXML_TYPE_GCDATA (gxml_gcdata_get_type ())
#define GXML_GCDATA(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCDATA, GXmlGCDATA))
#define GXML_GCDATA_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCDATA, GXmlGCDATAClass))
#define GXML_IS_GCDATA(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCDATA))
#define GXML_IS_GCDATA_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCDATA))
#define GXML_GCDATA_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCDATA, GXmlGCDATAClass))

typedef struct _GXmlGCDATA GXmlGCDATA;
typedef struct _GXmlGCDATAClass GXmlGCDATAClass;

#define GXML_TYPE_GPROCESSING_INSTRUCTION (gxml_gprocessing_instruction_get_type ())
#define GXML_GPROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstruction))
#define GXML_GPROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstructionClass))
#define GXML_IS_GPROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION))
#define GXML_IS_GPROCESSING_INSTRUCTION_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GPROCESSING_INSTRUCTION))
#define GXML_GPROCESSING_INSTRUCTION_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GPROCESSING_INSTRUCTION, GXmlGProcessingInstructionClass))

typedef struct _GXmlGProcessingInstruction GXmlGProcessingInstruction;
typedef struct _GXmlGProcessingInstructionClass GXmlGProcessingInstructionClass;

#define GXML_TYPE_GCOMMENT (gxml_gcomment_get_type ())
#define GXML_GCOMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GCOMMENT, GXmlGComment))
#define GXML_GCOMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GCOMMENT, GXmlGCommentClass))
#define GXML_IS_GCOMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GCOMMENT))
#define GXML_IS_GCOMMENT_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GCOMMENT))
#define GXML_GCOMMENT_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GCOMMENT, GXmlGCommentClass))

typedef struct _GXmlGComment GXmlGComment;
typedef struct _GXmlGCommentClass GXmlGCommentClass;

#define GXML_TYPE_DOCUMENT_TYPE (gxml_document_type_get_type ())
#define GXML_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_DOCUMENT_TYPE, GXmlDocumentType))
#define GXML_IS_DOCUMENT_TYPE(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_DOCUMENT_TYPE))
#define GXML_DOCUMENT_TYPE_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_DOCUMENT_TYPE, GXmlDocumentTypeIface))

typedef struct _GXmlDocumentType GXmlDocumentType;
typedef struct _GXmlDocumentTypeIface GXmlDocumentTypeIface;

#define GXML_TYPE_GHASH_MAP_ATTR (gxml_ghash_map_attr_get_type ())
#define GXML_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttr))
#define GXML_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))
#define GXML_IS_GHASH_MAP_ATTR(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_IS_GHASH_MAP_ATTR_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GHASH_MAP_ATTR))
#define GXML_GHASH_MAP_ATTR_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GHASH_MAP_ATTR, GXmlGHashMapAttrClass))

typedef struct _GXmlGHashMapAttr GXmlGHashMapAttr;
typedef struct _GXmlGHashMapAttrClass GXmlGHashMapAttrClass;

#define GXML_TYPE_GLIST_CHILDREN (gxml_glist_children_get_type ())
#define GXML_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildren))
#define GXML_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))
#define GXML_IS_GLIST_CHILDREN(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_CHILDREN))
#define GXML_IS_GLIST_CHILDREN_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_CHILDREN))
#define GXML_GLIST_CHILDREN_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_CHILDREN, GXmlGListChildrenClass))

typedef struct _GXmlGListChildren GXmlGListChildren;
typedef struct _GXmlGListChildrenClass GXmlGListChildrenClass;

#define GXML_TYPE_GLIST_NAMESPACES (gxml_glist_namespaces_get_type ())
#define GXML_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespaces))
#define GXML_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))
#define GXML_IS_GLIST_NAMESPACES(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_IS_GLIST_NAMESPACES_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), GXML_TYPE_GLIST_NAMESPACES))
#define GXML_GLIST_NAMESPACES_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), GXML_TYPE_GLIST_NAMESPACES, GXmlGListNamespacesClass))

typedef struct _GXmlGListNamespaces GXmlGListNamespaces;
typedef struct _GXmlGListNamespacesClass GXmlGListNamespacesClass;

#define GXML_TYPE_TEXT (gxml_text_get_type ())
#define GXML_TEXT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_TEXT, GXmlText))
#define GXML_IS_TEXT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_TEXT))
#define GXML_TEXT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_TEXT, GXmlTextIface))

typedef struct _GXmlText GXmlText;
typedef struct _GXmlTextIface GXmlTextIface;

#define GXML_TYPE_PROCESSING_INSTRUCTION (gxml_processing_instruction_get_type ())
#define GXML_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_PROCESSING_INSTRUCTION, GXmlProcessingInstruction))
#define GXML_IS_PROCESSING_INSTRUCTION(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_PROCESSING_INSTRUCTION))
#define GXML_PROCESSING_INSTRUCTION_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_PROCESSING_INSTRUCTION, GXmlProcessingInstructionIface))

typedef struct _GXmlProcessingInstruction GXmlProcessingInstruction;
typedef struct _GXmlProcessingInstructionIface GXmlProcessingInstructionIface;

#define GXML_TYPE_COMMENT (gxml_comment_get_type ())
#define GXML_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_COMMENT, GXmlComment))
#define GXML_IS_COMMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_COMMENT))
#define GXML_COMMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_COMMENT, GXmlCommentIface))

typedef struct _GXmlComment GXmlComment;
typedef struct _GXmlCommentIface GXmlCommentIface;

#define GXML_TYPE_ELEMENT (gxml_element_get_type ())
#define GXML_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), GXML_TYPE_ELEMENT, GXmlElement))
#define GXML_IS_ELEMENT(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GXML_TYPE_ELEMENT))
#define GXML_ELEMENT_GET_INTERFACE(obj) (G_TYPE_INSTANCE_GET_INTERFACE ((obj), GXML_TYPE_ELEMENT, GXmlElementIface))

typedef struct _GXmlElement GXmlElement;
typedef struct _GXmlElementIface GXmlElementIface;

typedef enum  {
	GXML_ERROR_NOT_SUPPORTED,
	GXML_ERROR_PARSER,
	GXML_ERROR_WRITER
} GXmlError;
#define GXML_ERROR gxml_error_quark ()
typedef enum  {
	GXML_DOM_EVENT_PHASE_NONE = 0,
	GXML_DOM_EVENT_PHASE_CAPTURING_PHASE,
	GXML_DOM_EVENT_PHASE_AT_TARGET,
	GXML_DOM_EVENT_PHASE_BUBBLING_PHASE
} GXmlDomEventPhase;

struct _GXmlDomEventIface {
	GTypeInterface parent_iface;
	void (*stop_propagation) (GXmlDomEvent* self);
	void (*stop_immediate_propagation) (GXmlDomEvent* self);
	void (*prevent_default) (GXmlDomEvent* self);
	void (*init_event) (GXmlDomEvent* self, const gchar* type, gboolean bubbles, gboolean cancelable);
	const gchar* (*get_etype) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_event_target) (GXmlDomEvent* self);
	GXmlDomEventTarget* (*get_current_target) (GXmlDomEvent* self);
	gboolean (*get_bubbles) (GXmlDomEvent* self);
	gboolean (*get_cancelable) (GXmlDomEvent* self);
	gboolean (*get_is_trusted) (GXmlDomEvent* self);
	GXmlDomTimeStamp* (*get_time_stamp) (GXmlDomEvent* self);
	gboolean (*get_default_prevented) (GXmlDomEvent* self);
	GXmlDomEventPhase (*get_event_phase) (GXmlDomEvent* self);
};

struct _GXmlDomEventListenerIface {
	GTypeInterface parent_iface;
	void (*handle_event) (GXmlDomEventListener* self, GXmlDomEvent* event);
};

struct _GXmlDomEventTargetIface {
	GTypeInterface parent_iface;
	void (*add_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	void (*remove_event_listener) (GXmlDomEventTarget* self, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
	gboolean (*dispatch_event) (GXmlDomEventTarget* self, GXmlDomEvent* event, GError** error);
};

typedef enum  {
	GXML_DOM_NODE_DOCUMENT_POSITION_NONE = 1 << 0,
	GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED = 1 << 1,
	GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING = 1 << 2,
	GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING = 1 << 3,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS = 1 << 4,
	GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY = 1 << 5,
	GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC = 1 << 6
} GXmlDomNodeDocumentPosition;

typedef enum  {
	GXML_DOM_NODE_NODE_TYPE_INVALID = 0,
	GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE = 1,
	GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE,
	GXML_DOM_NODE_NODE_TYPE_TEXT_NODE,
	GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE,
	GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE,
	GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE,
	GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE,
	GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE,
	GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE
} GXmlDomNodeNodeType;

struct _GXmlDomChildNodeIface {
	GTypeInterface parent_iface;
	void (*remove) (GXmlDomChildNode* self);
};

struct _GXmlDomNonDocumentTypeChildNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_previous_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
	GXmlDomElement* (*get_next_element_sibling) (GXmlDomNonDocumentTypeChildNode* self);
};

struct _GXmlDomHTMLCollectionIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement** (*to_array) (GXmlDomHTMLCollection* self, int* result_length1);
	GXmlDomElement* (*item) (GXmlDomHTMLCollection* self, gint index);
	GXmlDomElement* (*named_item) (GXmlDomHTMLCollection* self, const gchar* name);
	gint (*get_length) (GXmlDomHTMLCollection* self);
};

struct _GXmlDomTokenListIface {
	GTypeInterface parent_iface;
	gchar* (*item) (GXmlDomTokenList* self, gint index);
	gboolean (*contains) (GXmlDomTokenList* self, const gchar* token, GError** error);
	void (*add) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1, GError** error);
	void (*remove) (GXmlDomTokenList* self, gchar** tokens, int tokens_length1);
	gboolean (*toggle) (GXmlDomTokenList* self, const gchar* token, gboolean force, gboolean _auto_, GError** error);
	gchar* (*to_string) (GXmlDomTokenList* self);
	gint (*get_length) (GXmlDomTokenList* self);
};

struct _GXmlDomNamedNodeMapIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNamedNodeMap* self, gint index);
	GXmlDomNode* (*get_named_item) (GXmlDomNamedNodeMap* self, const gchar* name);
	GXmlDomNode* (*set_named_item) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*remove_named_item) (GXmlDomNamedNodeMap* self, const gchar* name, GError** error);
	GXmlDomNode* (*remove_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* localName, GError** error);
	GXmlDomNode* (*get_named_item_ns) (GXmlDomNamedNodeMap* self, const gchar* namespace_uri, const gchar* local_name, GError** error);
	GXmlDomNode* (*set_named_item_ns) (GXmlDomNamedNodeMap* self, GXmlDomNode* node, GError** error);
	gint (*get_length) (GXmlDomNamedNodeMap* self);
};

struct _GXmlDomElementIface {
	GTypeInterface parent_iface;
	gchar* (*get_attribute) (GXmlDomElement* self, const gchar* name);
	gchar* (*get_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	void (*set_attribute) (GXmlDomElement* self, const gchar* name, const gchar* value, GError** error);
	void (*set_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* name, const gchar* value, GError** error);
	void (*remove_attribute) (GXmlDomElement* self, const gchar* name);
	void (*remove_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	gboolean (*has_attribute) (GXmlDomElement* self, const gchar* name);
	gboolean (*has_attribute_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomElement* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomElement* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomElement* self, const gchar* class_names);
	gchar* (*get_namespace_uri) (GXmlDomElement* self);
	gchar* (*get_prefix) (GXmlDomElement* self);
	gchar* (*get_local_name) (GXmlDomElement* self);
	gchar* (*get_tag_name) (GXmlDomElement* self);
	gchar* (*get_id) (GXmlDomElement* self);
	void (*set_id) (GXmlDomElement* self, const gchar* value);
	gchar* (*get_class_name) (GXmlDomElement* self);
	void (*set_class_name) (GXmlDomElement* self, const gchar* value);
	GXmlDomTokenList* (*get_class_list) (GXmlDomElement* self);
	GXmlDomNamedNodeMap* (*get_attributes) (GXmlDomElement* self);
};

struct _GXmlDomNodeListIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*item) (GXmlDomNodeList* self, gint index);
	gint (*get_length) (GXmlDomNodeList* self);
};

struct _GXmlDomParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*query_selector) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomNodeList* (*query_selector_all) (GXmlDomParentNode* self, const gchar* selectors, GError** error);
	GXmlDomElementList* (*get_elements_by_property_value) (GXmlDomParentNode* self, const gchar* property, const gchar* value);
	GXmlDomHTMLCollection* (*get_children) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_first_element_child) (GXmlDomParentNode* self);
	GXmlDomElement* (*get_last_element_child) (GXmlDomParentNode* self);
	gint (*get_child_element_count) (GXmlDomParentNode* self);
};

struct _GXmlDomNonElementParentNodeIface {
	GTypeInterface parent_iface;
	GXmlDomElement* (*get_element_by_id) (GXmlDomNonElementParentNode* self, const gchar* element_id, GError** error);
};

struct _GXmlDomDocumentFragmentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomCharacterDataIface {
	GTypeInterface parent_iface;
	gchar* (*substring_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*append_data) (GXmlDomCharacterData* self, const gchar* data);
	void (*insert_data) (GXmlDomCharacterData* self, gint offset, const gchar* data, GError** error);
	void (*delete_data) (GXmlDomCharacterData* self, gint offset, gint count, GError** error);
	void (*replace_data) (GXmlDomCharacterData* self, gint offset, gint count, const gchar* data, GError** error);
	gchar* (*get_data) (GXmlDomCharacterData* self);
	void (*set_data) (GXmlDomCharacterData* self, const gchar* value);
	gint (*get_length) (GXmlDomCharacterData* self);
};

struct _GXmlDomTextIface {
	GTypeInterface parent_iface;
	GXmlDomText* (*split_text) (GXmlDomText* self, gint offset, GError** error);
	gchar* (*get_whole_text) (GXmlDomText* self);
};

struct _GXmlDomCommentIface {
	GTypeInterface parent_iface;
};

struct _GXmlDomProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlDomProcessingInstruction* self);
};

typedef enum  {
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_START = 0,
	GXML_DOM_RANGE_BOUNDARY_POINTS_START_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_END,
	GXML_DOM_RANGE_BOUNDARY_POINTS_END_TO_START
} GXmlDomRangeBoundaryPoints;

struct _GXmlDomRangeIface {
	GTypeInterface parent_iface;
	void (*set_start) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_end) (GXmlDomRange* self, GXmlDomNode* node, gint offset, GError** error);
	void (*set_start_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_start_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_before) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*set_end_after) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*collapse) (GXmlDomRange* self, gboolean to_start, GError** error);
	void (*select_node) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	void (*select_node_contents) (GXmlDomRange* self, GXmlDomNode* node, GError** error);
	gint (*compare_boundary_points) (GXmlDomRange* self, GXmlDomRangeBoundaryPoints how, GXmlDomRange* sourceRange, GError** error);
	void (*delete_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*extract_contents) (GXmlDomRange* self, GError** error);
	GXmlDomDocumentFragment* (*clone_contents) (GXmlDomRange* self, GError** error);
	void (*insert_node) (GXmlDomRange* self, GXmlDomNode* node);
	void (*surround_contents) (GXmlDomRange* self, GXmlDomNode* newParent);
	GXmlDomRange* (*clone_range) (GXmlDomRange* self);
	void (*detach) (GXmlDomRange* self);
	gboolean (*is_point_in_range) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gshort (*compare_point) (GXmlDomRange* self, GXmlDomNode* node, gint offset);
	gboolean (*intersects_node) (GXmlDomRange* self, GXmlDomNode* node);
	gchar* (*to_string) (GXmlDomRange* self);
	GXmlDomNode* (*get_start_container) (GXmlDomRange* self);
	gint (*get_start_offset) (GXmlDomRange* self);
	GXmlDomNode* (*get_end_container) (GXmlDomRange* self);
	gint (*get_end_offset) (GXmlDomRange* self);
	gboolean (*get_collapsed) (GXmlDomRange* self);
	GXmlDomNode* (*get_common_ancestor_container) (GXmlDomRange* self);
};

struct _GXmlDomNodeIteratorIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*next_node) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*previous_node) (GXmlDomNodeIterator* self);
	void (*detach) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_root) (GXmlDomNodeIterator* self);
	GXmlDomNode* (*get_reference_node) (GXmlDomNodeIterator* self);
	gboolean (*get_pointer_before_reference_node) (GXmlDomNodeIterator* self);
	gint (*get_what_to_show) (GXmlDomNodeIterator* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomNodeIterator* self);
};

struct _GXmlDomTreeWalkerIface {
	GTypeInterface parent_iface;
	GXmlDomNode* (*parentNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*firstChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*lastChild) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextSibling) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*previousNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*nextNode) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_root) (GXmlDomTreeWalker* self);
	gint (*get_what_to_show) (GXmlDomTreeWalker* self);
	GXmlDomNodeFilter* (*get_filter) (GXmlDomTreeWalker* self);
	GXmlDomNode* (*get_current_node) (GXmlDomTreeWalker* self);
};

struct _GXmlDomDocumentTypeIface {
	GTypeInterface parent_iface;
	const gchar* (*get_name) (GXmlDomDocumentType* self);
	const gchar* (*get_public_id) (GXmlDomDocumentType* self);
	const gchar* (*get_system_id) (GXmlDomDocumentType* self);
};

struct _GXmlDomXMLDocumentIface {
	GTypeInterface parent_iface;
};

struct _GXmlNamespaceIface {
	GTypeInterface parent_iface;
	gchar* (*get_uri) (GXmlNamespace* self);
	gchar* (*get_prefix) (GXmlNamespace* self);
};

typedef enum  {
	GXML_NODE_TYPE_INVALID = 0,
	GXML_NODE_TYPE_ELEMENT = 1,
	GXML_NODE_TYPE_ATTRIBUTE,
	GXML_NODE_TYPE_TEXT,
	GXML_NODE_TYPE_CDATA_SECTION,
	GXML_NODE_TYPE_ENTITY_REFERENCE,
	GXML_NODE_TYPE_ENTITY,
	GXML_NODE_TYPE_PROCESSING_INSTRUCTION,
	GXML_NODE_TYPE_COMMENT,
	GXML_NODE_TYPE_DOCUMENT,
	GXML_NODE_TYPE_DOCUMENT_TYPE,
	GXML_NODE_TYPE_DOCUMENT_FRAGMENT,
	GXML_NODE_TYPE_NOTATION
} GXmlNodeType;

struct _GXmlNodeIface {
	GTypeInterface parent_iface;
	GXmlNode* (*get) (GXmlNode* self, const gchar* key);
	GXmlElementList* (*get_elements_by_property_value) (GXmlNode* self, const gchar* property, const gchar* value);
	GXmlElementList* (*get_elements_by_name) (GXmlNode* self, const gchar* name);
	GXmlElementList* (*get_elements_by_name_ns) (GXmlNode* self, const gchar* name, const gchar* ns);
	gchar* (*to_string) (GXmlNode* self);
	gboolean (*set_namespace) (GXmlNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*ns_prefix) (GXmlNode* self);
	gchar* (*ns_uri) (GXmlNode* self);
	GeeList* (*get_namespaces) (GXmlNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlNode* self);
	GeeMap* (*get_attrs) (GXmlNode* self);
	gchar* (*get_name) (GXmlNode* self);
	gchar* (*get_value) (GXmlNode* self);
	void (*set_value) (GXmlNode* self, const gchar* value);
	GXmlNodeType (*get_type_node) (GXmlNode* self);
	GXmlDocument* (*get_document) (GXmlNode* self);
	GXmlNode* (*get_parent) (GXmlNode* self);
};

struct _GXmlDocumentIface {
	GTypeInterface parent_iface;
	GXmlNode* (*create_element) (GXmlDocument* self, const gchar* name, GError** error);
	GXmlNode* (*create_text) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_comment) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_cdata) (GXmlDocument* self, const gchar* text);
	GXmlNode* (*create_pi) (GXmlDocument* self, const gchar* target, const gchar* data);
	gboolean (*save) (GXmlDocument* self, GCancellable* cancellable, GError** error);
	gboolean (*save_as) (GXmlDocument* self, GFile* f, GCancellable* cancellable, GError** error);
	gboolean (*get_indent) (GXmlDocument* self);
	void (*set_indent) (GXmlDocument* self, gboolean value);
	gboolean (*get_ns_top) (GXmlDocument* self);
	void (*set_ns_top) (GXmlDocument* self, gboolean value);
	gboolean (*get_prefix_default_ns) (GXmlDocument* self);
	void (*set_prefix_default_ns) (GXmlDocument* self, gboolean value);
	gboolean (*get_backup) (GXmlDocument* self);
	void (*set_backup) (GXmlDocument* self, gboolean value);
	GXmlNode* (*get_root) (GXmlDocument* self);
	GFile* (*get_file) (GXmlDocument* self);
	void (*set_file) (GXmlDocument* self, GFile* value);
};

struct _GXmlDomImplementationIface {
	GTypeInterface parent_iface;
	GXmlDomDocumentType* (*create_document_type) (GXmlDomImplementation* self, const gchar* qualified_name, const gchar* public_id, const gchar* system_id, GError** error);
	GXmlDomXMLDocument* (*create_document) (GXmlDomImplementation* self, const gchar* nspace, const gchar* qualified_name, GXmlDomDocumentType* doctype, GError** error);
	GXmlDocument* (*create_html_document) (GXmlDomImplementation* self, const gchar* title);
	gboolean (*has_feature) (GXmlDomImplementation* self);
};

struct _GXmlDomDocumentIface {
	GTypeInterface parent_iface;
	GXmlDomHTMLCollection* (*get_elements_by_tag_name) (GXmlDomDocument* self, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_tag_name_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* local_name);
	GXmlDomHTMLCollection* (*get_elements_by_class_name) (GXmlDomDocument* self, const gchar* classNames);
	GXmlDomElement* (*create_element) (GXmlDomDocument* self, const gchar* local_name, GError** error);
	GXmlDomElement* (*create_element_ns) (GXmlDomDocument* self, const gchar* namespace, const gchar* qualified_name, GError** error);
	GXmlDomDocumentFragment* (*create_document_fragment) (GXmlDomDocument* self);
	GXmlDomText* (*create_text_node) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomComment* (*create_comment) (GXmlDomDocument* self, const gchar* data, GError** error);
	GXmlDomProcessingInstruction* (*create_processing_instruction) (GXmlDomDocument* self, const gchar* target, const gchar* data, GError** error);
	GXmlDomNode* (*import_node) (GXmlDomDocument* self, GXmlDomNode* node, gboolean deep, GError** error);
	GXmlDomNode* (*adopt_node) (GXmlDomDocument* self, GXmlDomNode* node, GError** error);
	GXmlDomEvent* (*create_event) (GXmlDomDocument* self, const gchar* interface, GError** error);
	GXmlDomRange* (*create_range) (GXmlDomDocument* self);
	GXmlDomNodeIterator* (*create_node_iterator) (GXmlDomDocument* self, GXmlDomNode* root, gint whatToShow, GXmlDomNodeFilter* filter);
	GXmlDomTreeWalker* (*create_tree_walker) (GXmlDomDocument* self, GXmlDomNode* root, gint what_to_show, GXmlDomNodeFilter* filter);
	GXmlDomImplementation* (*get_implementation) (GXmlDomDocument* self);
	const gchar* (*get_url) (GXmlDomDocument* self);
	const gchar* (*get_document_uri) (GXmlDomDocument* self);
	const gchar* (*get_origin) (GXmlDomDocument* self);
	const gchar* (*get_compat_mode) (GXmlDomDocument* self);
	const gchar* (*get_character_set) (GXmlDomDocument* self);
	const gchar* (*get_content_type) (GXmlDomDocument* self);
	GXmlDomDocumentType* (*get_doctype) (GXmlDomDocument* self);
	GXmlDomElement* (*get_document_element) (GXmlDomDocument* self);
};

struct _GXmlDomNodeIface {
	GTypeInterface parent_iface;
	gboolean (*has_child_nodes) (GXmlDomNode* self);
	void (*normalize) (GXmlDomNode* self);
	gboolean (*is_equal_node) (GXmlDomNode* self, GXmlDomNode* node);
	GXmlDomNodeDocumentPosition (*compare_document_position) (GXmlDomNode* self, GXmlDomNode* other);
	gboolean (*contains) (GXmlDomNode* self, GXmlDomNode* other);
	gchar* (*lookup_prefix) (GXmlDomNode* self, const gchar* nspace);
	gchar* (*lookup_namespace_uri) (GXmlDomNode* self, const gchar* prefix);
	gboolean (*is_default_namespace) (GXmlDomNode* self, const gchar* nspace);
	GXmlDomNode* (*insert_before) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*append_child) (GXmlDomNode* self, GXmlDomNode* node, GError** error);
	GXmlDomNode* (*replace_child) (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*remove_child) (GXmlDomNode* self, GXmlDomNode* child, GError** error);
	GXmlDomNode* (*clone_node) (GXmlDomNode* self, gboolean deep, GError** error);
	GXmlDomNodeNodeType (*get_node_type) (GXmlDomNode* self);
	gchar* (*get_node_name) (GXmlDomNode* self);
	const gchar* (*get_base_uri) (GXmlDomNode* self);
	GXmlDomDocument* (*get_owner_document) (GXmlDomNode* self);
	void (*set_owner_document) (GXmlDomNode* self, GXmlDomDocument* value);
	GXmlDomNode* (*get_parent_node) (GXmlDomNode* self);
	GXmlDomElement* (*get_parent_element) (GXmlDomNode* self);
	GXmlDomNodeList* (*get_child_nodes) (GXmlDomNode* self);
	GXmlDomNode* (*get_first_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_last_child) (GXmlDomNode* self);
	GXmlDomNode* (*get_previous_sibling) (GXmlDomNode* self);
	GXmlDomNode* (*get_next_sibling) (GXmlDomNode* self);
	gchar* (*get_node_value) (GXmlDomNode* self);
	void (*set_node_value) (GXmlDomNode* self, const gchar* value);
	gchar* (*get_text_content) (GXmlDomNode* self);
	void (*set_text_content) (GXmlDomNode* self, const gchar* value);
};

struct _GXmlGNode {
	GObject parent_instance;
	GXmlGNodePrivate * priv;
	GXmlGDocument* _doc;
	xmlNode* _node;
	gchar* _base_uri;
};

struct _GXmlGNodeClass {
	GObjectClass parent_class;
	gboolean (*set_namespace) (GXmlGNode* self, const gchar* uri, const gchar* prefix);
	gchar* (*to_string) (GXmlGNode* self);
	GeeMap* (*get_attrs) (GXmlGNode* self);
	GeeBidirList* (*get_children_nodes) (GXmlGNode* self);
	GeeList* (*get_namespaces) (GXmlGNode* self);
	GXmlDocument* (*get_document) (GXmlGNode* self);
	GXmlNode* (*get_parent) (GXmlGNode* self);
	GXmlNodeType (*get_type_node) (GXmlGNode* self);
	gchar* (*get_name) (GXmlGNode* self);
	gchar* (*get_value) (GXmlGNode* self);
	void (*set_value) (GXmlGNode* self, const gchar* value);
};

struct _GXmlDocumentTypeIface {
	GTypeInterface parent_iface;
};

typedef enum  {
	GXML_DOM_ERROR_INDEX_SIZE_ERROR = 1,
	GXML_DOM_ERROR_DOMSTRING_SIZE_ERROR,
	GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR,
	GXML_DOM_ERROR_WRONG_DOCUMENT_ERROR,
	GXML_DOM_ERROR_INVALID_CHARACTER_ERROR,
	GXML_DOM_ERROR_NO_DATA_ALLOWED_ERROR,
	GXML_DOM_ERROR_NO_MODIFICATION_ALLOWED_ERROR,
	GXML_DOM_ERROR_NOT_FOUND_ERROR,
	GXML_DOM_ERROR_NOT_SUPPORTED_ERROR,
	GXML_DOM_ERROR_INUSE_ATTRIBUTE_ERROR,
	GXML_DOM_ERROR_INVALID_STATE_ERROR,
	GXML_DOM_ERROR_SYNTAX_ERROR,
	GXML_DOM_ERROR_INVALID_MODIFICATION_ERROR,
	GXML_DOM_ERROR_NAMESPACE_ERROR,
	GXML_DOM_ERROR_INVALID_ACCESS_ERROR,
	GXML_DOM_ERROR_VALIDATION_ERROR,
	GXML_DOM_ERROR_TYPE_MISMATCH_ERROR,
	GXML_DOM_ERROR_SECURITY_ERROR,
	GXML_DOM_ERROR_NETWORK_ERROR,
	GXML_DOM_ERROR_ABORT_ERROR,
	GXML_DOM_ERROR_URL_MISMATCH_ERROR,
	GXML_DOM_ERROR_QUOTA_EXCEEDED_ERROR,
	GXML_DOM_ERROR_TIME_OUT_ERROR,
	GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR,
	GXML_DOM_ERROR_DATA_CLONE_ERROR
} GXmlDomError;
#define GXML_DOM_ERROR gxml_dom_error_quark ()
struct _GXmlTextIface {
	GTypeInterface parent_iface;
	gchar* (*get_str) (GXmlText* self);
	void (*set_str) (GXmlText* self, const gchar* value);
};

struct _GXmlProcessingInstructionIface {
	GTypeInterface parent_iface;
	gchar* (*get_target) (GXmlProcessingInstruction* self);
	gchar* (*get_data) (GXmlProcessingInstruction* self);
	void (*set_data) (GXmlProcessingInstruction* self, const gchar* value);
};

struct _GXmlCommentIface {
	GTypeInterface parent_iface;
	gchar* (*get_str) (GXmlComment* self);
	void (*set_str) (GXmlComment* self, const gchar* value);
};

struct _GXmlElementIface {
	GTypeInterface parent_iface;
	void (*normalize) (GXmlElement* self);
	void (*set_attr) (GXmlElement* self, const gchar* name, const gchar* value);
	GXmlNode* (*get_attr) (GXmlElement* self, const gchar* name);
	void (*remove_attr) (GXmlElement* self, const gchar* name);
	void (*remove_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	void (*set_ns_attr) (GXmlElement* self, const gchar* ns, const gchar* name, const gchar* value);
	GXmlNode* (*get_ns_attr) (GXmlElement* self, const gchar* name, const gchar* uri);
	gchar* (*get_tag_name) (GXmlElement* self);
	gchar* (*get_content) (GXmlElement* self);
	void (*set_content) (GXmlElement* self, const gchar* value);
};


static gpointer gxml_gnode_parent_class = NULL;
static GXmlDomEventTargetIface* gxml_gnode_gxml_dom_event_target_parent_iface = NULL;
static GXmlDomNodeIface* gxml_gnode_gxml_dom_node_parent_iface = NULL;
static GXmlNodeIface* gxml_gnode_gxml_node_parent_iface = NULL;

GQuark gxml_error_quark (void);
GType gxml_dom_time_stamp_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_phase_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_listener_get_type (void) G_GNUC_CONST;
GType gxml_dom_event_target_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_document_position_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_node_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_document_type_child_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_html_collection_get_type (void) G_GNUC_CONST;
GType gxml_dom_token_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_named_node_map_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_element_list_get_type (void) G_GNUC_CONST;
GType gxml_dom_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_non_element_parent_node_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_fragment_get_type (void) G_GNUC_CONST;
GType gxml_dom_character_data_get_type (void) G_GNUC_CONST;
GType gxml_dom_text_get_type (void) G_GNUC_CONST;
GType gxml_dom_comment_get_type (void) G_GNUC_CONST;
GType gxml_dom_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_boundary_points_get_type (void) G_GNUC_CONST;
GType gxml_dom_range_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_filter_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_iterator_get_type (void) G_GNUC_CONST;
GType gxml_dom_tree_walker_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_type_get_type (void) G_GNUC_CONST;
GType gxml_dom_xml_document_get_type (void) G_GNUC_CONST;
GType gxml_element_list_get_type (void) G_GNUC_CONST;
GType gxml_namespace_get_type (void) G_GNUC_CONST;
GType gxml_node_type_get_type (void) G_GNUC_CONST;
GType gxml_node_get_type (void) G_GNUC_CONST;
GType gxml_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_implementation_get_type (void) G_GNUC_CONST;
GType gxml_dom_document_get_type (void) G_GNUC_CONST;
GType gxml_dom_node_get_type (void) G_GNUC_CONST;
GType gxml_gnode_get_type (void) G_GNUC_CONST;
GType gxml_gdocument_get_type (void) G_GNUC_CONST;
enum  {
	GXML_GNODE_DUMMY_PROPERTY,
	GXML_GNODE_ATTRS,
	GXML_GNODE_CHILDREN_NODES,
	GXML_GNODE_NAMESPACES,
	GXML_GNODE_DOCUMENT,
	GXML_GNODE_PARENT,
	GXML_GNODE_TYPE_NODE,
	GXML_GNODE_NAME,
	GXML_GNODE_VALUE,
	GXML_GNODE_NODE_TYPE,
	GXML_GNODE_NODE_NAME,
	GXML_GNODE_BASE_URI,
	GXML_GNODE_OWNER_DOCUMENT,
	GXML_GNODE_PARENT_NODE,
	GXML_GNODE_PARENT_ELEMENT,
	GXML_GNODE_CHILD_NODES,
	GXML_GNODE_FIRST_CHILD,
	GXML_GNODE_LAST_CHILD,
	GXML_GNODE_PREVIOUS_SIBLING,
	GXML_GNODE_NEXT_SIBLING,
	GXML_GNODE_NODE_VALUE,
	GXML_GNODE_TEXT_CONTENT
};
gchar* gxml_gnode_libxml2_error_to_string (xmlError* e);
const gchar* xml_error_level_to_string (xmlErrorLevel self);
static const char* _xml_error_level_to_string (xmlErrorLevel value);
gboolean gxml_gnode_set_namespace (GXmlGNode* self, const gchar* uri, const gchar* prefix);
static gboolean gxml_gnode_real_set_namespace (GXmlGNode* self, const gchar* uri, const gchar* prefix);
gchar* gxml_gnode_to_string (GXmlGNode* self);
static gchar* gxml_gnode_real_to_string (GXmlGNode* self);
xmlNode* gxml_gnode_get_internal_node (GXmlGNode* self);
GXmlNode* gxml_gnode_to_gnode (GXmlGDocument* doc, xmlNode* node);
GXmlGElement* gxml_gelement_new (GXmlGDocument* doc, xmlNode* node);
GXmlGElement* gxml_gelement_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_gchild_node_get_type (void) G_GNUC_CONST;
GType gxml_gnon_document_child_node_get_type (void) G_GNUC_CONST;
GType gxml_gelement_get_type (void) G_GNUC_CONST;
GXmlGAttribute* gxml_gattribute_new (GXmlGDocument* doc, xmlAttr* node);
GXmlGAttribute* gxml_gattribute_construct (GType object_type, GXmlGDocument* doc, xmlAttr* node);
GType gxml_gattribute_get_type (void) G_GNUC_CONST;
GXmlGText* gxml_gtext_new (GXmlGDocument* doc, xmlNode* node);
GXmlGText* gxml_gtext_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_gcharacter_data_get_type (void) G_GNUC_CONST;
GType gxml_gtext_get_type (void) G_GNUC_CONST;
GXmlGCDATA* gxml_gcdata_new (GXmlGDocument* doc, xmlNode* node);
GXmlGCDATA* gxml_gcdata_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_gcdata_get_type (void) G_GNUC_CONST;
GXmlGProcessingInstruction* gxml_gprocessing_instruction_new (GXmlGDocument* doc, xmlNode* node);
GXmlGProcessingInstruction* gxml_gprocessing_instruction_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_gprocessing_instruction_get_type (void) G_GNUC_CONST;
GXmlGComment* gxml_gcomment_new (GXmlGDocument* doc, xmlNode* node);
GXmlGComment* gxml_gcomment_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_gcomment_get_type (void) G_GNUC_CONST;
GXmlGDocument* gxml_gdocument_new_from_doc (xmlDoc* doc);
GXmlGDocument* gxml_gdocument_construct_from_doc (GType object_type, xmlDoc* doc);
static gboolean gxml_gnode_real_has_child_nodes (GXmlDomNode* base);
GeeBidirList* gxml_gnode_get_children_nodes (GXmlGNode* self);
static void gxml_gnode_real_normalize (GXmlDomNode* base);
GXmlDomNodeList* gxml_dom_node_get_child_nodes (GXmlDomNode* self);
static GXmlDomNode* gxml_gnode_real_clone_node (GXmlDomNode* base, gboolean deep, GError** error);
static gboolean gxml_gnode_real_is_equal_node (GXmlDomNode* base, GXmlDomNode* node);
GeeBidirList* gxml_node_get_children_nodes (GXmlNode* self);
GeeMap* gxml_gnode_get_attrs (GXmlGNode* self);
GeeMap* gxml_node_get_attrs (GXmlNode* self);
gchar* gxml_node_get_name (GXmlNode* self);
gchar* gxml_node_get_value (GXmlNode* self);
gboolean gxml_dom_node_is_equal_node (GXmlDomNode* self, GXmlDomNode* node);
static GXmlDomNodeDocumentPosition gxml_gnode_real_compare_document_position (GXmlDomNode* base, GXmlDomNode* other);
GXmlDocument* gxml_gnode_get_document (GXmlGNode* self);
GXmlDocument* gxml_node_get_document (GXmlNode* self);
GXmlDomNode* gxml_dom_node_get_parent_node (GXmlDomNode* self);
gboolean gxml_dom_node_contains (GXmlDomNode* self, GXmlDomNode* other);
static gboolean gxml_gnode_real_contains (GXmlDomNode* base, GXmlDomNode* other);
static gchar* gxml_gnode_real_lookup_prefix (GXmlDomNode* base, const gchar* nspace);
GXmlNode* gxml_gnode_get_parent (GXmlGNode* self);
GType gxml_document_type_get_type (void) G_GNUC_CONST;
static gchar* gxml_gnode_real_lookup_namespace_uri (GXmlDomNode* base, const gchar* prefix);
static gboolean gxml_gnode_real_is_default_namespace (GXmlDomNode* base, const gchar* nspace);
gchar* gxml_dom_node_lookup_namespace_uri (GXmlDomNode* self, const gchar* prefix);
static GXmlDomNode* gxml_gnode_real_insert_before (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error);
GQuark gxml_dom_error_quark (void);
static GXmlDomNode* gxml_gnode_real_append_child (GXmlDomNode* base, GXmlDomNode* node, GError** error);
GXmlDomNode* gxml_dom_node_insert_before (GXmlDomNode* self, GXmlDomNode* node, GXmlDomNode* child, GError** error);
static GXmlDomNode* gxml_gnode_real_replace_child (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error);
static GXmlDomNode* gxml_gnode_real_remove_child (GXmlDomNode* base, GXmlDomNode* child, GError** error);
static void gxml_gnode_real_add_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
static void gxml_gnode_real_remove_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture);
static gboolean gxml_gnode_real_dispatch_event (GXmlDomEventTarget* base, GXmlDomEvent* event, GError** error);
GXmlGNode* gxml_gnode_construct (GType object_type);
GXmlGHashMapAttr* gxml_ghash_map_attr_new (GXmlGDocument* doc, xmlNode* node);
GXmlGHashMapAttr* gxml_ghash_map_attr_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_ghash_map_attr_get_type (void) G_GNUC_CONST;
GXmlGListChildren* gxml_glist_children_new (GXmlGDocument* doc, xmlNode* node);
GXmlGListChildren* gxml_glist_children_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_glist_children_get_type (void) G_GNUC_CONST;
GeeList* gxml_gnode_get_namespaces (GXmlGNode* self);
GXmlGListNamespaces* gxml_glist_namespaces_new (GXmlGDocument* doc, xmlNode* node);
GXmlGListNamespaces* gxml_glist_namespaces_construct (GType object_type, GXmlGDocument* doc, xmlNode* node);
GType gxml_glist_namespaces_get_type (void) G_GNUC_CONST;
GXmlNodeType gxml_gnode_get_type_node (GXmlGNode* self);
gchar* gxml_gnode_get_name (GXmlGNode* self);
gchar* gxml_gnode_get_value (GXmlGNode* self);
void gxml_gnode_set_value (GXmlGNode* self, const gchar* value);
GType gxml_text_get_type (void) G_GNUC_CONST;
GType gxml_processing_instruction_get_type (void) G_GNUC_CONST;
GType gxml_comment_get_type (void) G_GNUC_CONST;
GType gxml_element_get_type (void) G_GNUC_CONST;
GXmlNode* gxml_document_create_text (GXmlDocument* self, const gchar* text);
static GObject * gxml_gnode_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties);
void gxml_init_init (void);
static void gxml_gnode_finalize (GObject* obj);
GXmlDomNodeNodeType gxml_dom_node_get_node_type (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_name (GXmlDomNode* self);
const gchar* gxml_dom_node_get_base_uri (GXmlDomNode* self);
GXmlDomDocument* gxml_dom_node_get_owner_document (GXmlDomNode* self);
GXmlDomElement* gxml_dom_node_get_parent_element (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_first_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_last_child (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_previous_sibling (GXmlDomNode* self);
GXmlDomNode* gxml_dom_node_get_next_sibling (GXmlDomNode* self);
gchar* gxml_dom_node_get_node_value (GXmlDomNode* self);
gchar* gxml_dom_node_get_text_content (GXmlDomNode* self);
static void _vala_gxml_gnode_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec);
void gxml_dom_node_set_owner_document (GXmlDomNode* self, GXmlDomDocument* value);
void gxml_dom_node_set_node_value (GXmlDomNode* self, const gchar* value);
void gxml_dom_node_set_text_content (GXmlDomNode* self, const gchar* value);
static void _vala_gxml_gnode_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec);


GQuark gxml_error_quark (void) {
	return g_quark_from_static_string ("gxml_error-quark");
}


static const char* _xml_error_level_to_string (xmlErrorLevel value) {
	switch (value) {
		case XML_ERR_NONE:
		return "XML_ERR_NONE";
		case XML_ERR_WARNING:
		return "XML_ERR_WARNING";
		case XML_ERR_ERROR:
		return "XML_ERR_ERROR";
		case XML_ERR_FATAL:
		return "XML_ERR_FATAL";
	}
	return NULL;
}


static gchar* string_replace (const gchar* self, const gchar* old, const gchar* replacement) {
	gchar* result = NULL;
	GError * _inner_error_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	g_return_val_if_fail (old != NULL, NULL);
	g_return_val_if_fail (replacement != NULL, NULL);
	{
		GRegex* regex = NULL;
		const gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		gchar* _tmp2_ = NULL;
		GRegex* _tmp3_ = NULL;
		GRegex* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		GRegex* _tmp6_ = NULL;
		const gchar* _tmp7_ = NULL;
		gchar* _tmp8_ = NULL;
		gchar* _tmp9_ = NULL;
		_tmp0_ = old;
		_tmp1_ = g_regex_escape_string (_tmp0_, -1);
		_tmp2_ = _tmp1_;
		_tmp3_ = g_regex_new (_tmp2_, 0, 0, &_inner_error_);
		_tmp4_ = _tmp3_;
		_g_free0 (_tmp2_);
		regex = _tmp4_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch12_g_regex_error;
			}
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		_tmp6_ = regex;
		_tmp7_ = replacement;
		_tmp8_ = g_regex_replace_literal (_tmp6_, self, (gssize) -1, 0, _tmp7_, 0, &_inner_error_);
		_tmp5_ = _tmp8_;
		if (G_UNLIKELY (_inner_error_ != NULL)) {
			_g_regex_unref0 (regex);
			if (_inner_error_->domain == G_REGEX_ERROR) {
				goto __catch12_g_regex_error;
			}
			_g_regex_unref0 (regex);
			g_critical ("file %s: line %d: unexpected error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
			g_clear_error (&_inner_error_);
			return NULL;
		}
		_tmp9_ = _tmp5_;
		_tmp5_ = NULL;
		result = _tmp9_;
		_g_free0 (_tmp5_);
		_g_regex_unref0 (regex);
		return result;
	}
	goto __finally12;
	__catch12_g_regex_error:
	{
		GError* e = NULL;
		e = _inner_error_;
		_inner_error_ = NULL;
		g_assert_not_reached ();
		_g_error_free0 (e);
	}
	__finally12:
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
		g_clear_error (&_inner_error_);
		return NULL;
	}
}


gchar* gxml_gnode_libxml2_error_to_string (xmlError* e) {
	gchar* result = NULL;
	const gchar* _tmp0_ = NULL;
	xmlError* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp5_ = NULL;
	xmlError* _tmp6_ = NULL;
	xmlErrorLevel _tmp7_ = 0;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	gchar* _tmp10_ = NULL;
	xmlError* _tmp11_ = NULL;
	gint _tmp12_ = 0;
	gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	gchar* _tmp15_ = NULL;
	gchar* _tmp16_ = NULL;
	xmlError* _tmp17_ = NULL;
	gint _tmp18_ = 0;
	xmlError* _tmp19_ = NULL;
	gint _tmp20_ = 0;
	xmlError* _tmp21_ = NULL;
	const gchar* _tmp22_ = NULL;
	gchar* _tmp23_ = NULL;
	gchar* _tmp24_ = NULL;
	_tmp1_ = e;
	_tmp2_ = (*_tmp1_).file;
	if (_tmp2_ == NULL) {
		_tmp0_ = "<io>";
	} else {
		xmlError* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		_tmp3_ = e;
		_tmp4_ = (*_tmp3_).file;
		_tmp0_ = _tmp4_;
	}
	_tmp5_ = _ ("%s:%s:%d: %s:%d: %s");
	_tmp6_ = e;
	_tmp7_ = (*_tmp6_).level;
	_tmp8_ = _xml_error_level_to_string (_tmp7_);
	_tmp9_ = string_replace (_tmp8_, "XML_ERR_", "");
	_tmp10_ = _tmp9_;
	_tmp11_ = e;
	_tmp12_ = (*_tmp11_).domain;
	_tmp13_ = g_strdup_printf ("%i", _tmp12_);
	_tmp14_ = _tmp13_;
	_tmp15_ = string_replace (_tmp14_, "XML_FROM_", "");
	_tmp16_ = _tmp15_;
	_tmp17_ = e;
	_tmp18_ = (*_tmp17_).code;
	_tmp19_ = e;
	_tmp20_ = (*_tmp19_).line;
	_tmp21_ = e;
	_tmp22_ = (*_tmp21_).message;
	_tmp23_ = g_strdup_printf (_tmp5_, _tmp10_, _tmp16_, _tmp18_, _tmp0_, _tmp20_, _tmp22_);
	_tmp24_ = _tmp23_;
	_g_free0 (_tmp16_);
	_g_free0 (_tmp14_);
	_g_free0 (_tmp10_);
	result = _tmp24_;
	return result;
}


static gboolean gxml_gnode_real_set_namespace (GXmlGNode* self, const gchar* uri, const gchar* prefix) {
	gboolean result = FALSE;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	xmlNs* _tmp4_ = NULL;
	g_return_val_if_fail (uri != NULL, FALSE);
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = uri;
	_tmp3_ = prefix;
	_tmp4_ = xmlNewNs (_tmp1_, (xmlChar*) _tmp2_, (xmlChar*) _tmp3_);
	result = _tmp4_ != NULL;
	return result;
}


gboolean gxml_gnode_set_namespace (GXmlGNode* self, const gchar* uri, const gchar* prefix) {
	g_return_val_if_fail (self != NULL, FALSE);
	return GXML_GNODE_GET_CLASS (self)->set_namespace (self, uri, prefix);
}


static gchar* gxml_gnode_real_to_string (GXmlGNode* self) {
	gchar* result = NULL;
	GType _tmp0_ = 0UL;
	const gchar* _tmp1_ = NULL;
	gchar* _tmp2_ = NULL;
	_tmp0_ = G_TYPE_FROM_INSTANCE ((GObject*) self);
	_tmp1_ = g_type_name (_tmp0_);
	_tmp2_ = g_strdup (_tmp1_);
	result = _tmp2_;
	return result;
}


gchar* gxml_gnode_to_string (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->to_string (self);
}


xmlNode* gxml_gnode_get_internal_node (GXmlGNode* self) {
	xmlNode* result = NULL;
	xmlNode* _tmp0_ = NULL;
	g_return_val_if_fail (self != NULL, NULL);
	_tmp0_ = self->_node;
	result = _tmp0_;
	return result;
}


GXmlNode* gxml_gnode_to_gnode (GXmlGDocument* doc, xmlNode* node) {
	GXmlNode* result = NULL;
	GXmlNode* nullnode = NULL;
	GXmlNodeType t = 0;
	xmlNode* _tmp0_ = NULL;
	xmlElementType _tmp1_ = 0;
	GXmlNodeType _tmp2_ = 0;
	g_return_val_if_fail (doc != NULL, NULL);
	nullnode = NULL;
	_tmp0_ = node;
	_tmp1_ = _tmp0_->type;
	t = (GXmlNodeType) _tmp1_;
	_tmp2_ = t;
	switch (_tmp2_) {
		case GXML_NODE_TYPE_ELEMENT:
		{
			GXmlGDocument* _tmp3_ = NULL;
			xmlNode* _tmp4_ = NULL;
			GXmlGElement* _tmp5_ = NULL;
			_tmp3_ = doc;
			_tmp4_ = node;
			_tmp5_ = gxml_gelement_new (_tmp3_, _tmp4_);
			result = (GXmlNode*) _tmp5_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_ATTRIBUTE:
		{
			GXmlGDocument* _tmp6_ = NULL;
			xmlNode* _tmp7_ = NULL;
			GXmlGAttribute* _tmp8_ = NULL;
			_tmp6_ = doc;
			_tmp7_ = node;
			_tmp8_ = gxml_gattribute_new (_tmp6_, (xmlAttr*) _tmp7_);
			result = (GXmlNode*) _tmp8_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_TEXT:
		{
			GXmlGDocument* _tmp9_ = NULL;
			xmlNode* _tmp10_ = NULL;
			GXmlGText* _tmp11_ = NULL;
			_tmp9_ = doc;
			_tmp10_ = node;
			_tmp11_ = gxml_gtext_new (_tmp9_, _tmp10_);
			result = (GXmlNode*) _tmp11_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_CDATA_SECTION:
		{
			GXmlGDocument* _tmp12_ = NULL;
			xmlNode* _tmp13_ = NULL;
			GXmlGCDATA* _tmp14_ = NULL;
			_tmp12_ = doc;
			_tmp13_ = node;
			_tmp14_ = gxml_gcdata_new (_tmp12_, _tmp13_);
			result = (GXmlNode*) _tmp14_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_ENTITY_REFERENCE:
		{
			result = nullnode;
			return result;
		}
		case GXML_NODE_TYPE_ENTITY:
		{
			result = nullnode;
			return result;
		}
		case GXML_NODE_TYPE_PROCESSING_INSTRUCTION:
		{
			GXmlGDocument* _tmp15_ = NULL;
			xmlNode* _tmp16_ = NULL;
			GXmlGProcessingInstruction* _tmp17_ = NULL;
			_tmp15_ = doc;
			_tmp16_ = node;
			_tmp17_ = gxml_gprocessing_instruction_new (_tmp15_, _tmp16_);
			result = (GXmlNode*) _tmp17_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_COMMENT:
		{
			GXmlGDocument* _tmp18_ = NULL;
			xmlNode* _tmp19_ = NULL;
			GXmlGComment* _tmp20_ = NULL;
			_tmp18_ = doc;
			_tmp19_ = node;
			_tmp20_ = gxml_gcomment_new (_tmp18_, _tmp19_);
			result = (GXmlNode*) _tmp20_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_DOCUMENT:
		{
			xmlNode* _tmp21_ = NULL;
			xmlDoc* _tmp22_ = NULL;
			GXmlGDocument* _tmp23_ = NULL;
			_tmp21_ = node;
			_tmp22_ = _tmp21_->doc;
			_tmp23_ = gxml_gdocument_new_from_doc (_tmp22_);
			result = (GXmlNode*) _tmp23_;
			_g_object_unref0 (nullnode);
			return result;
		}
		case GXML_NODE_TYPE_DOCUMENT_TYPE:
		{
			result = nullnode;
			return result;
		}
		case GXML_NODE_TYPE_DOCUMENT_FRAGMENT:
		{
			result = nullnode;
			return result;
		}
		case GXML_NODE_TYPE_NOTATION:
		{
			result = nullnode;
			return result;
		}
		default:
		break;
	}
	result = nullnode;
	return result;
}


static gboolean gxml_gnode_real_has_child_nodes (GXmlDomNode* base) {
	GXmlGNode * self;
	gboolean result = FALSE;
	GeeBidirList* _tmp0_ = NULL;
	GeeBidirList* _tmp1_ = NULL;
	GeeBidirList* _tmp2_ = NULL;
	gint _tmp3_ = 0;
	gint _tmp4_ = 0;
	gboolean _tmp5_ = FALSE;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_children_nodes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_collection_get_size ((GeeCollection*) _tmp2_);
	_tmp4_ = _tmp3_;
	_tmp5_ = _tmp4_ > 0;
	_g_object_unref0 (_tmp2_);
	result = _tmp5_;
	return result;
}


static void gxml_gnode_real_normalize (GXmlDomNode* base) {
	GXmlGNode * self;
	self = (GXmlGNode*) base;
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp0_ = FALSE;
			_tmp0_ = TRUE;
			while (TRUE) {
				gint _tmp2_ = 0;
				GeeBidirList* _tmp3_ = NULL;
				GeeBidirList* _tmp4_ = NULL;
				GeeBidirList* _tmp5_ = NULL;
				gint _tmp6_ = 0;
				gint _tmp7_ = 0;
				gboolean _tmp8_ = FALSE;
				GXmlNode* n = NULL;
				GeeBidirList* _tmp9_ = NULL;
				GeeBidirList* _tmp10_ = NULL;
				GeeBidirList* _tmp11_ = NULL;
				gint _tmp12_ = 0;
				gpointer _tmp13_ = NULL;
				GXmlNode* _tmp14_ = NULL;
				GXmlNode* _tmp15_ = NULL;
				if (!_tmp0_) {
					gint _tmp1_ = 0;
					_tmp1_ = i;
					i = _tmp1_ + 1;
				}
				_tmp0_ = FALSE;
				_tmp2_ = i;
				_tmp3_ = gxml_gnode_get_children_nodes (self);
				_tmp4_ = _tmp3_;
				_tmp5_ = _tmp4_;
				_tmp6_ = gee_collection_get_size ((GeeCollection*) _tmp5_);
				_tmp7_ = _tmp6_;
				_tmp8_ = !(_tmp2_ < _tmp7_);
				_g_object_unref0 (_tmp5_);
				if (_tmp8_) {
					break;
				}
				_tmp9_ = gxml_gnode_get_children_nodes (self);
				_tmp10_ = _tmp9_;
				_tmp11_ = _tmp10_;
				_tmp12_ = i;
				_tmp13_ = gee_list_get ((GeeList*) _tmp11_, _tmp12_);
				_tmp14_ = (GXmlNode*) _tmp13_;
				_g_object_unref0 (_tmp11_);
				n = _tmp14_;
				_tmp15_ = n;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp15_, GXML_TYPE_DOM_TEXT)) {
					GXmlDomNodeList* _tmp16_ = NULL;
					GXmlDomNodeList* _tmp17_ = NULL;
					GXmlDomNodeList* _tmp18_ = NULL;
					gint _tmp19_ = 0;
					gpointer _tmp20_ = NULL;
					GXmlDomNode* _tmp21_ = NULL;
					_tmp16_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
					_tmp17_ = _tmp16_;
					_tmp18_ = _tmp17_;
					_tmp19_ = i;
					_tmp20_ = gee_list_remove_at ((GeeList*) _tmp18_, _tmp19_);
					_tmp21_ = (GXmlDomNode*) _tmp20_;
					_g_object_unref0 (_tmp21_);
					_g_object_unref0 (_tmp18_);
				}
				_g_object_unref0 (n);
			}
		}
	}
}


static GXmlDomNode* gxml_gnode_real_clone_node (GXmlDomNode* base, gboolean deep, GError** error) {
	GXmlGNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* nullnode = NULL;
	xmlNode* n = NULL;
	gboolean _tmp0_ = FALSE;
	xmlNode* _tmp5_ = NULL;
	GXmlGDocument* _tmp6_ = NULL;
	xmlNode* _tmp7_ = NULL;
	GXmlNode* _tmp8_ = NULL;
	self = (GXmlGNode*) base;
	nullnode = NULL;
	n = NULL;
	_tmp0_ = deep;
	if (_tmp0_) {
		xmlNode* _tmp1_ = NULL;
		xmlNode* _tmp2_ = NULL;
		_tmp1_ = self->_node;
		_tmp2_ = xmlCopyNode (_tmp1_, 1);
		n = _tmp2_;
	} else {
		xmlNode* _tmp3_ = NULL;
		xmlNode* _tmp4_ = NULL;
		_tmp3_ = self->_node;
		_tmp4_ = xmlCopyNode (_tmp3_, 2);
		n = _tmp4_;
	}
	_tmp5_ = n;
	if (_tmp5_ == NULL) {
		result = nullnode;
		return result;
	}
	_tmp6_ = self->_doc;
	_tmp7_ = n;
	_tmp8_ = gxml_gnode_to_gnode (_tmp6_, _tmp7_);
	result = G_TYPE_CHECK_INSTANCE_CAST (_tmp8_, GXML_TYPE_DOM_NODE, GXmlDomNode);
	_g_object_unref0 (nullnode);
	return result;
}


static gboolean gxml_gnode_real_is_equal_node (GXmlDomNode* base, GXmlDomNode* node) {
	GXmlGNode * self;
	gboolean result = FALSE;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GeeBidirList* _tmp2_ = NULL;
	GeeBidirList* _tmp3_ = NULL;
	GeeBidirList* _tmp4_ = NULL;
	gint _tmp5_ = 0;
	gint _tmp6_ = 0;
	GXmlDomNode* _tmp7_ = NULL;
	GeeBidirList* _tmp8_ = NULL;
	GeeBidirList* _tmp9_ = NULL;
	GeeBidirList* _tmp10_ = NULL;
	gint _tmp11_ = 0;
	gint _tmp12_ = 0;
	gboolean _tmp13_ = FALSE;
	self = (GXmlGNode*) base;
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_NODE)) {
		result = FALSE;
		return result;
	}
	_tmp1_ = node;
	if (_tmp1_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp2_ = gxml_gnode_get_children_nodes (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_;
	_tmp5_ = gee_collection_get_size ((GeeCollection*) _tmp4_);
	_tmp6_ = _tmp5_;
	_tmp7_ = node;
	_tmp8_ = gxml_node_get_children_nodes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp7_) : NULL);
	_tmp9_ = _tmp8_;
	_tmp10_ = _tmp9_;
	_tmp11_ = gee_collection_get_size ((GeeCollection*) _tmp10_);
	_tmp12_ = _tmp11_;
	_tmp13_ = _tmp6_ != _tmp12_;
	_g_object_unref0 (_tmp10_);
	_g_object_unref0 (_tmp4_);
	if (_tmp13_) {
		result = FALSE;
		return result;
	}
	{
		GeeIterator* _a_it = NULL;
		GeeMap* _tmp14_ = NULL;
		GeeMap* _tmp15_ = NULL;
		GeeMap* _tmp16_ = NULL;
		GeeCollection* _tmp17_ = NULL;
		GeeCollection* _tmp18_ = NULL;
		GeeCollection* _tmp19_ = NULL;
		GeeIterator* _tmp20_ = NULL;
		GeeIterator* _tmp21_ = NULL;
		_tmp14_ = gxml_gnode_get_attrs (self);
		_tmp15_ = _tmp14_;
		_tmp16_ = _tmp15_;
		_tmp17_ = gee_map_get_values (_tmp16_);
		_tmp18_ = _tmp17_;
		_tmp19_ = _tmp18_;
		_tmp20_ = gee_iterable_iterator ((GeeIterable*) _tmp19_);
		_tmp21_ = _tmp20_;
		_g_object_unref0 (_tmp19_);
		_g_object_unref0 (_tmp16_);
		_a_it = _tmp21_;
		while (TRUE) {
			GeeIterator* _tmp22_ = NULL;
			gboolean _tmp23_ = FALSE;
			GXmlNode* a = NULL;
			GeeIterator* _tmp24_ = NULL;
			gpointer _tmp25_ = NULL;
			GXmlDomNode* _tmp26_ = NULL;
			GeeMap* _tmp27_ = NULL;
			GeeMap* _tmp28_ = NULL;
			GeeMap* _tmp29_ = NULL;
			GXmlNode* _tmp30_ = NULL;
			gchar* _tmp31_ = NULL;
			gchar* _tmp32_ = NULL;
			gchar* _tmp33_ = NULL;
			gboolean _tmp34_ = FALSE;
			gboolean _tmp35_ = FALSE;
			GXmlNode* _tmp36_ = NULL;
			gchar* _tmp37_ = NULL;
			gchar* _tmp38_ = NULL;
			gchar* _tmp39_ = NULL;
			GXmlDomNode* _tmp40_ = NULL;
			GeeMap* _tmp41_ = NULL;
			GeeMap* _tmp42_ = NULL;
			GeeMap* _tmp43_ = NULL;
			GXmlNode* _tmp44_ = NULL;
			gchar* _tmp45_ = NULL;
			gchar* _tmp46_ = NULL;
			gchar* _tmp47_ = NULL;
			gpointer _tmp48_ = NULL;
			GXmlNode* _tmp49_ = NULL;
			gchar* _tmp50_ = NULL;
			gchar* _tmp51_ = NULL;
			gchar* _tmp52_ = NULL;
			gboolean _tmp53_ = FALSE;
			_tmp22_ = _a_it;
			_tmp23_ = gee_iterator_next (_tmp22_);
			if (!_tmp23_) {
				break;
			}
			_tmp24_ = _a_it;
			_tmp25_ = gee_iterator_get (_tmp24_);
			a = (GXmlNode*) _tmp25_;
			_tmp26_ = node;
			_tmp27_ = gxml_node_get_attrs (G_TYPE_CHECK_INSTANCE_TYPE (_tmp26_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp26_) : NULL);
			_tmp28_ = _tmp27_;
			_tmp29_ = _tmp28_;
			_tmp30_ = a;
			_tmp31_ = gxml_node_get_name (_tmp30_);
			_tmp32_ = _tmp31_;
			_tmp33_ = _tmp32_;
			_tmp34_ = gee_map_has_key (_tmp29_, _tmp33_);
			_tmp35_ = !_tmp34_;
			_g_free0 (_tmp33_);
			_g_object_unref0 (_tmp29_);
			if (_tmp35_) {
				result = FALSE;
				_g_object_unref0 (a);
				_g_object_unref0 (_a_it);
				return result;
			}
			_tmp36_ = a;
			_tmp37_ = gxml_node_get_value (_tmp36_);
			_tmp38_ = _tmp37_;
			_tmp39_ = _tmp38_;
			_tmp40_ = node;
			_tmp41_ = gxml_node_get_attrs (G_TYPE_CHECK_INSTANCE_TYPE (_tmp40_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp40_) : NULL);
			_tmp42_ = _tmp41_;
			_tmp43_ = _tmp42_;
			_tmp44_ = a;
			_tmp45_ = gxml_node_get_name (_tmp44_);
			_tmp46_ = _tmp45_;
			_tmp47_ = _tmp46_;
			_tmp48_ = gee_map_get (_tmp43_, _tmp47_);
			_tmp49_ = (GXmlNode*) _tmp48_;
			_tmp50_ = gxml_node_get_value (_tmp49_);
			_tmp51_ = _tmp50_;
			_tmp52_ = _tmp51_;
			_tmp53_ = g_strcmp0 (_tmp39_, _tmp52_) != 0;
			_g_free0 (_tmp52_);
			_g_object_unref0 (_tmp49_);
			_g_free0 (_tmp47_);
			_g_object_unref0 (_tmp43_);
			_g_free0 (_tmp39_);
			if (_tmp53_) {
				result = FALSE;
				_g_object_unref0 (a);
				_g_object_unref0 (_a_it);
				return result;
			}
			_g_object_unref0 (a);
		}
		_g_object_unref0 (_a_it);
	}
	{
		gint i = 0;
		i = 0;
		{
			gboolean _tmp54_ = FALSE;
			_tmp54_ = TRUE;
			while (TRUE) {
				gint _tmp56_ = 0;
				GeeBidirList* _tmp57_ = NULL;
				GeeBidirList* _tmp58_ = NULL;
				GeeBidirList* _tmp59_ = NULL;
				gint _tmp60_ = 0;
				gint _tmp61_ = 0;
				gboolean _tmp62_ = FALSE;
				GeeBidirList* _tmp63_ = NULL;
				GeeBidirList* _tmp64_ = NULL;
				GeeBidirList* _tmp65_ = NULL;
				gint _tmp66_ = 0;
				gpointer _tmp67_ = NULL;
				GXmlNode* _tmp68_ = NULL;
				GXmlDomNode* _tmp69_ = NULL;
				GXmlDomNode* _tmp70_ = NULL;
				GXmlDomNode* _tmp71_ = NULL;
				GeeBidirList* _tmp72_ = NULL;
				GeeBidirList* _tmp73_ = NULL;
				GeeBidirList* _tmp74_ = NULL;
				gint _tmp75_ = 0;
				gpointer _tmp76_ = NULL;
				GXmlNode* _tmp77_ = NULL;
				GXmlDomNode* _tmp78_ = NULL;
				GXmlDomNode* _tmp79_ = NULL;
				gboolean _tmp80_ = FALSE;
				gboolean _tmp81_ = FALSE;
				if (!_tmp54_) {
					gint _tmp55_ = 0;
					_tmp55_ = i;
					i = _tmp55_ + 1;
				}
				_tmp54_ = FALSE;
				_tmp56_ = i;
				_tmp57_ = gxml_gnode_get_children_nodes (self);
				_tmp58_ = _tmp57_;
				_tmp59_ = _tmp58_;
				_tmp60_ = gee_collection_get_size ((GeeCollection*) _tmp59_);
				_tmp61_ = _tmp60_;
				_tmp62_ = !(_tmp56_ < _tmp61_);
				_g_object_unref0 (_tmp59_);
				if (_tmp62_) {
					break;
				}
				_tmp63_ = gxml_gnode_get_children_nodes (self);
				_tmp64_ = _tmp63_;
				_tmp65_ = _tmp64_;
				_tmp66_ = i;
				_tmp67_ = gee_list_get ((GeeList*) _tmp65_, _tmp66_);
				_tmp68_ = (GXmlNode*) _tmp67_;
				_tmp69_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp68_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp68_) : NULL;
				if (_tmp69_ == NULL) {
					_g_object_unref0 (_tmp68_);
				}
				_tmp70_ = _tmp69_;
				_tmp71_ = node;
				_tmp72_ = gxml_node_get_children_nodes (G_TYPE_CHECK_INSTANCE_TYPE (_tmp71_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp71_) : NULL);
				_tmp73_ = _tmp72_;
				_tmp74_ = _tmp73_;
				_tmp75_ = i;
				_tmp76_ = gee_list_get ((GeeList*) _tmp74_, _tmp75_);
				_tmp77_ = (GXmlNode*) _tmp76_;
				_tmp78_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp77_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp77_) : NULL;
				if (_tmp78_ == NULL) {
					_g_object_unref0 (_tmp77_);
				}
				_tmp79_ = _tmp78_;
				_tmp80_ = gxml_dom_node_is_equal_node (_tmp70_, _tmp79_);
				_tmp81_ = !_tmp80_;
				_g_object_unref0 (_tmp79_);
				_g_object_unref0 (_tmp74_);
				_g_object_unref0 (_tmp70_);
				_g_object_unref0 (_tmp65_);
				if (_tmp81_) {
					result = FALSE;
					return result;
				}
			}
		}
	}
	result = TRUE;
	return result;
}


static GXmlDomNodeDocumentPosition gxml_gnode_real_compare_document_position (GXmlDomNode* base, GXmlDomNode* other) {
	GXmlGNode * self;
	GXmlDomNodeDocumentPosition result = 0;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	GXmlDocument* _tmp2_ = NULL;
	GXmlDocument* _tmp3_ = NULL;
	GXmlDomNode* _tmp4_ = NULL;
	GXmlDocument* _tmp5_ = NULL;
	GXmlDocument* _tmp6_ = NULL;
	GXmlDomNode* _tmp13_ = NULL;
	gboolean _tmp14_ = FALSE;
	GXmlDomNode* _tmp15_ = NULL;
	GXmlDomNode* _tmp16_ = NULL;
	GXmlDomNode* _tmp17_ = NULL;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp19_ = FALSE;
	gboolean _tmp20_ = FALSE;
	GXmlDomNode* _tmp35_ = NULL;
	gboolean _tmp36_ = FALSE;
	const gchar* _tmp37_ = NULL;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (other != NULL, 0);
	_tmp0_ = other;
	if ((G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) self) : NULL) == _tmp0_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_NONE;
		return result;
	}
	_tmp2_ = gxml_gnode_get_document (self);
	_tmp3_ = _tmp2_;
	_tmp4_ = other;
	_tmp5_ = gxml_node_get_document (G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp4_) : NULL);
	_tmp6_ = _tmp5_;
	if (_tmp3_ != _tmp6_) {
		_tmp1_ = TRUE;
	} else {
		GXmlDomNode* _tmp7_ = NULL;
		GXmlDomNode* _tmp8_ = NULL;
		GXmlDomNode* _tmp9_ = NULL;
		GXmlDomNode* _tmp10_ = NULL;
		_tmp7_ = other;
		_tmp8_ = gxml_dom_node_get_parent_node (_tmp7_);
		_tmp9_ = _tmp8_;
		_tmp10_ = _tmp9_;
		_tmp1_ = _tmp10_ == NULL;
		_g_object_unref0 (_tmp10_);
	}
	if (_tmp1_) {
		GXmlDomNodeDocumentPosition p = 0;
		p = GXML_DOM_NODE_DOCUMENT_POSITION_DISCONNECTED & GXML_DOM_NODE_DOCUMENT_POSITION_IMPLEMENTATION_SPECIFIC;
		if ((&self) > (&other)) {
			GXmlDomNodeDocumentPosition _tmp11_ = 0;
			_tmp11_ = p;
			p = _tmp11_ & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
		} else {
			GXmlDomNodeDocumentPosition _tmp12_ = 0;
			_tmp12_ = p;
			p = _tmp12_ & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
		}
		result = p;
		return result;
	}
	_tmp13_ = other;
	_tmp14_ = gxml_dom_node_contains (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) self) : NULL, _tmp13_);
	if (_tmp14_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINED_BY & GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
		return result;
	}
	_tmp15_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
	_tmp16_ = _tmp15_;
	_tmp17_ = _tmp16_;
	_tmp18_ = other;
	_tmp19_ = gxml_dom_node_contains (_tmp17_, _tmp18_);
	_tmp20_ = _tmp19_;
	_g_object_unref0 (_tmp17_);
	if (_tmp20_) {
		GXmlDomNode* par = NULL;
		GXmlDomNode* _tmp21_ = NULL;
		GXmlDomNode* _tmp22_ = NULL;
		GXmlDomNode* _tmp23_ = NULL;
		GXmlDomNodeList* _tmp24_ = NULL;
		GXmlDomNodeList* _tmp25_ = NULL;
		GXmlDomNodeList* _tmp26_ = NULL;
		gint _tmp27_ = 0;
		GXmlDomNode* _tmp28_ = NULL;
		GXmlDomNodeList* _tmp29_ = NULL;
		GXmlDomNodeList* _tmp30_ = NULL;
		GXmlDomNodeList* _tmp31_ = NULL;
		GXmlDomNode* _tmp32_ = NULL;
		gint _tmp33_ = 0;
		gboolean _tmp34_ = FALSE;
		_tmp21_ = gxml_dom_node_get_parent_node ((GXmlDomNode*) self);
		_tmp22_ = _tmp21_;
		par = _tmp22_;
		_tmp23_ = par;
		_tmp24_ = gxml_dom_node_get_child_nodes (_tmp23_);
		_tmp25_ = _tmp24_;
		_tmp26_ = _tmp25_;
		_tmp27_ = gee_list_index_of ((GeeList*) _tmp26_, (GXmlDomNode*) self);
		_tmp28_ = par;
		_tmp29_ = gxml_dom_node_get_child_nodes (_tmp28_);
		_tmp30_ = _tmp29_;
		_tmp31_ = _tmp30_;
		_tmp32_ = other;
		_tmp33_ = gee_list_index_of ((GeeList*) _tmp31_, _tmp32_);
		_tmp34_ = _tmp27_ > _tmp33_;
		_g_object_unref0 (_tmp31_);
		_g_object_unref0 (_tmp26_);
		if (_tmp34_) {
			result = GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
			_g_object_unref0 (par);
			return result;
		} else {
			result = GXML_DOM_NODE_DOCUMENT_POSITION_FOLLOWING;
			_g_object_unref0 (par);
			return result;
		}
		_g_object_unref0 (par);
	}
	_tmp35_ = other;
	_tmp36_ = gxml_dom_node_contains (_tmp35_, (GXmlDomNode*) self);
	if (_tmp36_) {
		result = GXML_DOM_NODE_DOCUMENT_POSITION_CONTAINS & GXML_DOM_NODE_DOCUMENT_POSITION_PRECEDING;
		return result;
	}
	_tmp37_ = _ ("Can't find node position");
	g_warning ("GXmlNode.vala:276: %s", _tmp37_);
	result = GXML_DOM_NODE_DOCUMENT_POSITION_NONE;
	return result;
}


static gboolean gxml_gnode_real_contains (GXmlDomNode* base, GXmlDomNode* other) {
	GXmlGNode * self;
	gboolean result = FALSE;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNodeList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	GXmlDomNodeList* _tmp3_ = NULL;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp5_ = FALSE;
	gboolean _tmp6_ = FALSE;
	self = (GXmlGNode*) base;
	_tmp0_ = other;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = other;
	_tmp5_ = gee_collection_contains ((GeeCollection*) _tmp3_, _tmp4_);
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp3_);
	result = _tmp6_;
	return result;
}


static gchar* gxml_gnode_real_lookup_prefix (GXmlDomNode* base, const gchar* nspace) {
	GXmlGNode * self;
	gchar* result = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	GXmlNode* _tmp3_ = NULL;
	gboolean _tmp4_ = FALSE;
	gboolean _tmp5_ = FALSE;
	xmlNs* ns = NULL;
	xmlNode* _tmp6_ = NULL;
	xmlDoc* _tmp7_ = NULL;
	xmlNode* _tmp8_ = NULL;
	const gchar* _tmp9_ = NULL;
	xmlNs* _tmp10_ = NULL;
	xmlNs* _tmp11_ = NULL;
	xmlNs* _tmp12_ = NULL;
	const gchar* _tmp13_ = NULL;
	gchar* _tmp14_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = gxml_gnode_get_parent (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = _tmp2_;
	_tmp4_ = _tmp3_ == NULL;
	_g_object_unref0 (_tmp3_);
	if (_tmp4_) {
		result = NULL;
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT_TYPE)) {
		_tmp5_ = TRUE;
	} else {
		_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (_tmp5_) {
		result = NULL;
		return result;
	}
	_tmp6_ = self->_node;
	_tmp7_ = _tmp6_->doc;
	_tmp8_ = self->_node;
	_tmp9_ = nspace;
	_tmp10_ = xmlSearchNsByHref (_tmp7_, _tmp8_, _tmp9_);
	ns = _tmp10_;
	_tmp11_ = ns;
	if (_tmp11_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp12_ = ns;
	_tmp13_ = _tmp12_->prefix;
	_tmp14_ = g_strdup (_tmp13_);
	result = _tmp14_;
	return result;
}


static gchar* gxml_gnode_real_lookup_namespace_uri (GXmlDomNode* base, const gchar* prefix) {
	GXmlGNode * self;
	gchar* result = NULL;
	gboolean _tmp0_ = FALSE;
	xmlNs* ns = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlDoc* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	const gchar* _tmp4_ = NULL;
	xmlNs* _tmp5_ = NULL;
	xmlNs* _tmp6_ = NULL;
	xmlNs* _tmp7_ = NULL;
	const gchar* _tmp8_ = NULL;
	gchar* _tmp9_ = NULL;
	self = (GXmlGNode*) base;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT_TYPE)) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (_tmp0_) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = _tmp1_->doc;
	_tmp3_ = self->_node;
	_tmp4_ = prefix;
	_tmp5_ = xmlSearchNs (_tmp2_, _tmp3_, _tmp4_);
	ns = _tmp5_;
	_tmp6_ = ns;
	if (_tmp6_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp7_ = ns;
	_tmp8_ = _tmp7_->href;
	_tmp9_ = g_strdup (_tmp8_);
	result = _tmp9_;
	return result;
}


static gboolean gxml_gnode_real_is_default_namespace (GXmlDomNode* base, const gchar* nspace) {
	GXmlGNode * self;
	gboolean result = FALSE;
	const gchar* _tmp0_ = NULL;
	gchar* ns = NULL;
	gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = nspace;
	if (_tmp0_ == NULL) {
		result = FALSE;
		return result;
	}
	_tmp1_ = gxml_dom_node_lookup_namespace_uri ((GXmlDomNode*) self, NULL);
	ns = _tmp1_;
	_tmp2_ = ns;
	_tmp3_ = nspace;
	if (g_strcmp0 (_tmp2_, _tmp3_) == 0) {
		result = TRUE;
		_g_free0 (ns);
		return result;
	}
	result = FALSE;
	_g_free0 (ns);
	return result;
}


static gpointer _g_object_ref0 (gpointer self) {
	return self ? g_object_ref (self) : NULL;
}


static GXmlDomNode* gxml_gnode_real_insert_before (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	GXmlGNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	GXmlDomNode* _tmp28_ = NULL;
	GXmlDomNode* _tmp33_ = NULL;
	GeeBidirList* _tmp47_ = NULL;
	GeeBidirList* _tmp48_ = NULL;
	GeeBidirList* _tmp49_ = NULL;
	GXmlDomNode* _tmp50_ = NULL;
	GXmlDomNode* _tmp51_ = NULL;
	GXmlDomNode* _tmp52_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GNODE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid attempt to add invalid node type");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = child;
	if (_tmp4_ != NULL) {
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		_tmp5_ = child;
		_tmp6_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp5_);
		_tmp3_ = !_tmp6_;
	} else {
		_tmp3_ = FALSE;
	}
	if (_tmp3_) {
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		_tmp7_ = _ ("Can't find child to insert node before");
		_tmp8_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp7_);
		_inner_error_ = _tmp8_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT)) {
		_tmp10_ = TRUE;
	} else {
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp10_) {
		_tmp9_ = TRUE;
	} else {
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (!_tmp9_) {
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		_tmp11_ = _ ("Invalid attempt to insert a node");
		_tmp12_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp11_);
		_inner_error_ = _tmp12_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT_FRAGMENT)) {
		_tmp17_ = TRUE;
	} else {
		GXmlDomNode* _tmp19_ = NULL;
		_tmp19_ = node;
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_DOCUMENT_TYPE);
	}
	if (_tmp17_) {
		_tmp16_ = TRUE;
	} else {
		GXmlDomNode* _tmp20_ = NULL;
		_tmp20_ = node;
		_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp16_) {
		_tmp15_ = TRUE;
	} else {
		GXmlDomNode* _tmp21_ = NULL;
		_tmp21_ = node;
		_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_TEXT);
	}
	if (_tmp15_) {
		_tmp14_ = TRUE;
	} else {
		GXmlDomNode* _tmp22_ = NULL;
		_tmp22_ = node;
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION);
	}
	if (_tmp14_) {
		_tmp13_ = TRUE;
	} else {
		GXmlDomNode* _tmp23_ = NULL;
		_tmp23_ = node;
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_COMMENT);
	}
	if (!_tmp13_) {
		const gchar* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		_tmp24_ = _ ("Invalid attempt to insert an invalid node type");
		_tmp25_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp24_);
		_inner_error_ = _tmp25_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp28_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_TEXT)) {
		_tmp27_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
	} else {
		_tmp27_ = FALSE;
	}
	if (_tmp27_) {
		_tmp26_ = TRUE;
	} else {
		gboolean _tmp29_ = FALSE;
		GXmlDomNode* _tmp30_ = NULL;
		_tmp30_ = node;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
			_tmp29_ = !G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
		} else {
			_tmp29_ = FALSE;
		}
		_tmp26_ = _tmp29_;
	}
	if (_tmp26_) {
		const gchar* _tmp31_ = NULL;
		GError* _tmp32_ = NULL;
		_tmp31_ = _ ("Invalid attempt to insert a document's type or text node to an invalid" \
" parent");
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp31_);
		_inner_error_ = _tmp32_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp33_ = child;
	if (_tmp33_ != NULL) {
		gint i = 0;
		GeeBidirList* _tmp34_ = NULL;
		GeeBidirList* _tmp35_ = NULL;
		GeeBidirList* _tmp36_ = NULL;
		GXmlDomNode* _tmp37_ = NULL;
		gint _tmp38_ = 0;
		gint _tmp39_ = 0;
		GeeBidirList* _tmp40_ = NULL;
		GeeBidirList* _tmp41_ = NULL;
		GeeBidirList* _tmp42_ = NULL;
		gint _tmp43_ = 0;
		GXmlDomNode* _tmp44_ = NULL;
		GXmlDomNode* _tmp45_ = NULL;
		GXmlDomNode* _tmp46_ = NULL;
		_tmp34_ = gxml_gnode_get_children_nodes (self);
		_tmp35_ = _tmp34_;
		_tmp36_ = _tmp35_;
		_tmp37_ = child;
		_tmp38_ = gee_list_index_of ((GeeList*) _tmp36_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp37_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp37_) : NULL);
		_tmp39_ = _tmp38_;
		_g_object_unref0 (_tmp36_);
		i = _tmp39_;
		_tmp40_ = gxml_gnode_get_children_nodes (self);
		_tmp41_ = _tmp40_;
		_tmp42_ = _tmp41_;
		_tmp43_ = i;
		_tmp44_ = node;
		gee_list_insert ((GeeList*) _tmp42_, _tmp43_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp44_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp44_) : NULL);
		_g_object_unref0 (_tmp42_);
		_tmp45_ = node;
		_tmp46_ = _g_object_ref0 (_tmp45_);
		result = _tmp46_;
		return result;
	}
	_tmp47_ = gxml_gnode_get_children_nodes (self);
	_tmp48_ = _tmp47_;
	_tmp49_ = _tmp48_;
	_tmp50_ = node;
	gee_collection_add ((GeeCollection*) _tmp49_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp50_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp50_) : NULL);
	_g_object_unref0 (_tmp49_);
	_tmp51_ = node;
	_tmp52_ = _g_object_ref0 (_tmp51_);
	result = _tmp52_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_append_child (GXmlDomNode* base, GXmlDomNode* node, GError** error) {
	GXmlGNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	GXmlDomNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	GXmlDomNode* _tmp3_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	_tmp1_ = node;
	_tmp2_ = gxml_dom_node_insert_before ((GXmlDomNode*) self, _tmp1_, NULL, &_inner_error_);
	_tmp0_ = _tmp2_;
	if (G_UNLIKELY (_inner_error_ != NULL)) {
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp3_ = _tmp0_;
	_tmp0_ = NULL;
	result = _tmp3_;
	_g_object_unref0 (_tmp0_);
	return result;
}


static GXmlDomNode* gxml_gnode_real_replace_child (GXmlDomNode* base, GXmlDomNode* node, GXmlDomNode* child, GError** error) {
	GXmlGNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp3_ = FALSE;
	GXmlDomNode* _tmp4_ = NULL;
	gboolean _tmp9_ = FALSE;
	gboolean _tmp10_ = FALSE;
	gboolean _tmp13_ = FALSE;
	gboolean _tmp14_ = FALSE;
	gboolean _tmp15_ = FALSE;
	gboolean _tmp16_ = FALSE;
	gboolean _tmp17_ = FALSE;
	GXmlDomNode* _tmp18_ = NULL;
	gboolean _tmp26_ = FALSE;
	gboolean _tmp27_ = FALSE;
	GXmlDomNode* _tmp28_ = NULL;
	gint i = 0;
	GeeBidirList* _tmp33_ = NULL;
	GeeBidirList* _tmp34_ = NULL;
	GeeBidirList* _tmp35_ = NULL;
	GXmlDomNode* _tmp36_ = NULL;
	gint _tmp37_ = 0;
	gint _tmp38_ = 0;
	GeeBidirList* _tmp39_ = NULL;
	GeeBidirList* _tmp40_ = NULL;
	GeeBidirList* _tmp41_ = NULL;
	gint _tmp42_ = 0;
	gpointer _tmp43_ = NULL;
	GXmlNode* _tmp44_ = NULL;
	gint _tmp45_ = 0;
	GeeBidirList* _tmp46_ = NULL;
	GeeBidirList* _tmp47_ = NULL;
	GeeBidirList* _tmp48_ = NULL;
	gint _tmp49_ = 0;
	gint _tmp50_ = 0;
	gboolean _tmp51_ = FALSE;
	gint _tmp57_ = 0;
	GeeBidirList* _tmp58_ = NULL;
	GeeBidirList* _tmp59_ = NULL;
	GeeBidirList* _tmp60_ = NULL;
	gint _tmp61_ = 0;
	gint _tmp62_ = 0;
	gboolean _tmp63_ = FALSE;
	GXmlDomNode* _tmp68_ = NULL;
	GXmlDomNode* _tmp69_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (node != NULL, NULL);
	g_return_val_if_fail (child != NULL, NULL);
	_tmp0_ = node;
	if (!G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GNODE)) {
		const gchar* _tmp1_ = NULL;
		GError* _tmp2_ = NULL;
		_tmp1_ = _ ("Invalid attempt to add invalid node type");
		_tmp2_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_INVALID_NODE_TYPE_ERROR, _tmp1_);
		_inner_error_ = _tmp2_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = child;
	if (_tmp4_ == NULL) {
		_tmp3_ = TRUE;
	} else {
		GXmlDomNode* _tmp5_ = NULL;
		gboolean _tmp6_ = FALSE;
		_tmp5_ = child;
		_tmp6_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp5_);
		_tmp3_ = !_tmp6_;
	}
	if (_tmp3_) {
		const gchar* _tmp7_ = NULL;
		GError* _tmp8_ = NULL;
		_tmp7_ = _ ("Can't find child node to replace or child have a different parent");
		_tmp8_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp7_);
		_inner_error_ = _tmp8_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT)) {
		_tmp10_ = TRUE;
	} else {
		_tmp10_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp10_) {
		_tmp9_ = TRUE;
	} else {
		_tmp9_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT_FRAGMENT);
	}
	if (!_tmp9_) {
		const gchar* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		_tmp11_ = _ ("Invalid attempt to insert a node");
		_tmp12_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp11_);
		_inner_error_ = _tmp12_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp18_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_DOM_DOCUMENT_FRAGMENT)) {
		_tmp17_ = TRUE;
	} else {
		GXmlDomNode* _tmp19_ = NULL;
		_tmp19_ = node;
		_tmp17_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp19_, GXML_TYPE_DOM_DOCUMENT_TYPE);
	}
	if (_tmp17_) {
		_tmp16_ = TRUE;
	} else {
		GXmlDomNode* _tmp20_ = NULL;
		_tmp20_ = node;
		_tmp16_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp20_, GXML_TYPE_DOM_ELEMENT);
	}
	if (_tmp16_) {
		_tmp15_ = TRUE;
	} else {
		GXmlDomNode* _tmp21_ = NULL;
		_tmp21_ = node;
		_tmp15_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp21_, GXML_TYPE_DOM_TEXT);
	}
	if (_tmp15_) {
		_tmp14_ = TRUE;
	} else {
		GXmlDomNode* _tmp22_ = NULL;
		_tmp22_ = node;
		_tmp14_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp22_, GXML_TYPE_DOM_PROCESSING_INSTRUCTION);
	}
	if (_tmp14_) {
		_tmp13_ = TRUE;
	} else {
		GXmlDomNode* _tmp23_ = NULL;
		_tmp23_ = node;
		_tmp13_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp23_, GXML_TYPE_DOM_COMMENT);
	}
	if (!_tmp13_) {
		const gchar* _tmp24_ = NULL;
		GError* _tmp25_ = NULL;
		_tmp24_ = _ ("Invalid attempt to insert an invalid node type");
		_tmp25_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp24_);
		_inner_error_ = _tmp25_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp28_ = node;
	if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp28_, GXML_TYPE_DOM_TEXT)) {
		_tmp27_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
	} else {
		_tmp27_ = FALSE;
	}
	if (_tmp27_) {
		_tmp26_ = TRUE;
	} else {
		gboolean _tmp29_ = FALSE;
		GXmlDomNode* _tmp30_ = NULL;
		_tmp30_ = node;
		if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp30_, GXML_TYPE_DOM_DOCUMENT_TYPE)) {
			_tmp29_ = !G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOM_DOCUMENT);
		} else {
			_tmp29_ = FALSE;
		}
		_tmp26_ = _tmp29_;
	}
	if (_tmp26_) {
		const gchar* _tmp31_ = NULL;
		GError* _tmp32_ = NULL;
		_tmp31_ = _ ("Invalid attempt to insert a document's type or text node to an invalid" \
" parent");
		_tmp32_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_HIERARCHY_REQUEST_ERROR, _tmp31_);
		_inner_error_ = _tmp32_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp33_ = gxml_gnode_get_children_nodes (self);
	_tmp34_ = _tmp33_;
	_tmp35_ = _tmp34_;
	_tmp36_ = child;
	_tmp37_ = gee_list_index_of ((GeeList*) _tmp35_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp36_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp36_) : NULL);
	_tmp38_ = _tmp37_;
	_g_object_unref0 (_tmp35_);
	i = _tmp38_;
	_tmp39_ = gxml_gnode_get_children_nodes (self);
	_tmp40_ = _tmp39_;
	_tmp41_ = _tmp40_;
	_tmp42_ = i;
	_tmp43_ = gee_list_remove_at ((GeeList*) _tmp41_, _tmp42_);
	_tmp44_ = (GXmlNode*) _tmp43_;
	_g_object_unref0 (_tmp44_);
	_g_object_unref0 (_tmp41_);
	_tmp45_ = i;
	_tmp46_ = gxml_gnode_get_children_nodes (self);
	_tmp47_ = _tmp46_;
	_tmp48_ = _tmp47_;
	_tmp49_ = gee_collection_get_size ((GeeCollection*) _tmp48_);
	_tmp50_ = _tmp49_;
	_tmp51_ = _tmp45_ < _tmp50_;
	_g_object_unref0 (_tmp48_);
	if (_tmp51_) {
		GeeBidirList* _tmp52_ = NULL;
		GeeBidirList* _tmp53_ = NULL;
		GeeBidirList* _tmp54_ = NULL;
		gint _tmp55_ = 0;
		GXmlDomNode* _tmp56_ = NULL;
		_tmp52_ = gxml_gnode_get_children_nodes (self);
		_tmp53_ = _tmp52_;
		_tmp54_ = _tmp53_;
		_tmp55_ = i;
		_tmp56_ = node;
		gee_list_insert ((GeeList*) _tmp54_, _tmp55_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp56_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp56_) : NULL);
		_g_object_unref0 (_tmp54_);
	}
	_tmp57_ = i;
	_tmp58_ = gxml_gnode_get_children_nodes (self);
	_tmp59_ = _tmp58_;
	_tmp60_ = _tmp59_;
	_tmp61_ = gee_collection_get_size ((GeeCollection*) _tmp60_);
	_tmp62_ = _tmp61_;
	_tmp63_ = _tmp57_ >= _tmp62_;
	_g_object_unref0 (_tmp60_);
	if (_tmp63_) {
		GXmlDomNodeList* _tmp64_ = NULL;
		GXmlDomNodeList* _tmp65_ = NULL;
		GXmlDomNodeList* _tmp66_ = NULL;
		GXmlDomNode* _tmp67_ = NULL;
		_tmp64_ = gxml_dom_node_get_child_nodes ((GXmlDomNode*) self);
		_tmp65_ = _tmp64_;
		_tmp66_ = _tmp65_;
		_tmp67_ = node;
		gee_collection_add ((GeeCollection*) _tmp66_, _tmp67_);
		_g_object_unref0 (_tmp66_);
	}
	_tmp68_ = child;
	_tmp69_ = _g_object_ref0 (_tmp68_);
	result = _tmp69_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_remove_child (GXmlDomNode* base, GXmlDomNode* child, GError** error) {
	GXmlGNode * self;
	GXmlDomNode* result = NULL;
	GXmlDomNode* _tmp0_ = NULL;
	gboolean _tmp1_ = FALSE;
	gint i = 0;
	GeeBidirList* _tmp4_ = NULL;
	GeeBidirList* _tmp5_ = NULL;
	GeeBidirList* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	gint _tmp8_ = 0;
	gint _tmp9_ = 0;
	GeeBidirList* _tmp10_ = NULL;
	GeeBidirList* _tmp11_ = NULL;
	GeeBidirList* _tmp12_ = NULL;
	gpointer _tmp13_ = NULL;
	GXmlDomNode* _tmp14_ = NULL;
	GError * _inner_error_ = NULL;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (child != NULL, NULL);
	_tmp0_ = child;
	_tmp1_ = gxml_dom_node_contains ((GXmlDomNode*) self, _tmp0_);
	if (!_tmp1_) {
		const gchar* _tmp2_ = NULL;
		GError* _tmp3_ = NULL;
		_tmp2_ = _ ("Can't find child node to remove or child have a different parent");
		_tmp3_ = g_error_new_literal (GXML_DOM_ERROR, GXML_DOM_ERROR_NOT_FOUND_ERROR, _tmp2_);
		_inner_error_ = _tmp3_;
		g_propagate_error (error, _inner_error_);
		return NULL;
	}
	_tmp4_ = gxml_gnode_get_children_nodes (self);
	_tmp5_ = _tmp4_;
	_tmp6_ = _tmp5_;
	_tmp7_ = child;
	_tmp8_ = gee_list_index_of ((GeeList*) _tmp6_, G_TYPE_CHECK_INSTANCE_TYPE (_tmp7_, GXML_TYPE_NODE) ? ((GXmlNode*) _tmp7_) : NULL);
	_tmp9_ = _tmp8_;
	_g_object_unref0 (_tmp6_);
	i = _tmp9_;
	_tmp10_ = gxml_gnode_get_children_nodes (self);
	_tmp11_ = _tmp10_;
	_tmp12_ = _tmp11_;
	_tmp13_ = gee_list_remove_at ((GeeList*) _tmp12_, i);
	_tmp14_ = G_TYPE_CHECK_INSTANCE_CAST ((GXmlNode*) _tmp13_, GXML_TYPE_DOM_NODE, GXmlDomNode);
	_g_object_unref0 (_tmp12_);
	result = _tmp14_;
	return result;
}


static void gxml_gnode_real_add_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture) {
	GXmlGNode * self;
	self = (GXmlGNode*) base;
	g_return_if_fail (type != NULL);
	return;
}


static void gxml_gnode_real_remove_event_listener (GXmlDomEventTarget* base, const gchar* type, GXmlDomEventListener* callback, gboolean capture) {
	GXmlGNode * self;
	self = (GXmlGNode*) base;
	g_return_if_fail (type != NULL);
	return;
}


static gboolean gxml_gnode_real_dispatch_event (GXmlDomEventTarget* base, GXmlDomEvent* event, GError** error) {
	GXmlGNode * self;
	gboolean result = FALSE;
	self = (GXmlGNode*) base;
	g_return_val_if_fail (event != NULL, FALSE);
	result = FALSE;
	return result;
}


GXmlGNode* gxml_gnode_construct (GType object_type) {
	GXmlGNode * self = NULL;
	self = (GXmlGNode*) g_object_new (object_type, NULL);
	return self;
}


GeeMap* gxml_gnode_get_attrs (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_attrs (self);
}


static GeeMap* gxml_gnode_real_get_attrs (GXmlGNode* base) {
	GeeMap* result;
	GXmlGNode* self;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGHashMapAttr* _tmp2_ = NULL;
	GeeMap* _tmp3_ = NULL;
	self = base;
	_tmp0_ = self->_doc;
	_tmp1_ = self->_node;
	_tmp2_ = gxml_ghash_map_attr_new (_tmp0_, _tmp1_);
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GEE_TYPE_MAP) ? ((GeeMap*) _tmp2_) : NULL;
	if (_tmp3_ == NULL) {
		_g_object_unref0 (_tmp2_);
	}
	result = _tmp3_;
	return result;
}


GeeBidirList* gxml_gnode_get_children_nodes (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_children_nodes (self);
}


static GeeBidirList* gxml_gnode_real_get_children_nodes (GXmlGNode* base) {
	GeeBidirList* result;
	GXmlGNode* self;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGListChildren* _tmp2_ = NULL;
	GeeBidirList* _tmp3_ = NULL;
	self = base;
	_tmp0_ = self->_doc;
	_tmp1_ = self->_node;
	_tmp2_ = gxml_glist_children_new (_tmp0_, _tmp1_);
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GEE_TYPE_BIDIR_LIST) ? ((GeeBidirList*) _tmp2_) : NULL;
	if (_tmp3_ == NULL) {
		_g_object_unref0 (_tmp2_);
	}
	result = _tmp3_;
	return result;
}


GeeList* gxml_gnode_get_namespaces (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_namespaces (self);
}


static GeeList* gxml_gnode_real_get_namespaces (GXmlGNode* base) {
	GeeList* result;
	GXmlGNode* self;
	GXmlGDocument* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	GXmlGListNamespaces* _tmp2_ = NULL;
	GeeList* _tmp3_ = NULL;
	self = base;
	_tmp0_ = self->_doc;
	_tmp1_ = self->_node;
	_tmp2_ = gxml_glist_namespaces_new (_tmp0_, _tmp1_);
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GEE_TYPE_LIST) ? ((GeeList*) _tmp2_) : NULL;
	if (_tmp3_ == NULL) {
		_g_object_unref0 (_tmp2_);
	}
	result = _tmp3_;
	return result;
}


GXmlDocument* gxml_gnode_get_document (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_document (self);
}


static GXmlDocument* gxml_gnode_real_get_document (GXmlGNode* base) {
	GXmlDocument* result;
	GXmlGNode* self;
	GXmlGDocument* _tmp0_ = NULL;
	self = base;
	_tmp0_ = self->_doc;
	result = (GXmlDocument*) _tmp0_;
	return result;
}


GXmlNode* gxml_gnode_get_parent (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_parent (self);
}


static GXmlNode* gxml_gnode_real_get_parent (GXmlGNode* base) {
	GXmlNode* result;
	GXmlGNode* self;
	GXmlNode* nullnode = NULL;
	xmlNode* _tmp0_ = NULL;
	GXmlDocument* _tmp1_ = NULL;
	GXmlDocument* _tmp2_ = NULL;
	xmlNode* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	GXmlNode* _tmp5_ = NULL;
	self = base;
	nullnode = NULL;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = nullnode;
		return result;
	}
	_tmp1_ = gxml_gnode_get_document (self);
	_tmp2_ = _tmp1_;
	_tmp3_ = self->_node;
	_tmp4_ = _tmp3_->parent;
	_tmp5_ = gxml_gnode_to_gnode (G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_GDOCUMENT) ? ((GXmlGDocument*) _tmp2_) : NULL, _tmp4_);
	result = _tmp5_;
	_g_object_unref0 (nullnode);
	return result;
}


GXmlNodeType gxml_gnode_get_type_node (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, 0);
	return GXML_GNODE_GET_CLASS (self)->get_type_node (self);
}


static GXmlNodeType gxml_gnode_real_get_type_node (GXmlGNode* base) {
	GXmlNodeType result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlElementType _tmp2_ = 0;
	self = base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = GXML_NODE_TYPE_INVALID;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = _tmp1_->type;
	result = (GXmlNodeType) _tmp2_;
	return result;
}


gchar* gxml_gnode_get_name (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_name (self);
}


static gchar* gxml_gnode_real_get_name (GXmlGNode* base) {
	gchar* result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	self = base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("#noname");
		result = _tmp1_;
		return result;
	}
	_tmp2_ = self->_node;
	_tmp3_ = _tmp2_->name;
	_tmp4_ = g_strdup (_tmp3_);
	result = _tmp4_;
	return result;
}


gchar* gxml_gnode_get_value (GXmlGNode* self) {
	g_return_val_if_fail (self != NULL, NULL);
	return GXML_GNODE_GET_CLASS (self)->get_value (self);
}


static gchar* gxml_gnode_real_get_value (GXmlGNode* base) {
	gchar* result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp2_ = NULL;
	gchar* _tmp3_ = NULL;
	self = base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		gchar* _tmp1_ = NULL;
		_tmp1_ = g_strdup ("");
		result = _tmp1_;
		return result;
	}
	_tmp2_ = self->_node;
	_tmp3_ = (gchar*) xmlNodeGetContent (_tmp2_);
	result = _tmp3_;
	return result;
}


void gxml_gnode_set_value (GXmlGNode* self, const gchar* value) {
	g_return_if_fail (self != NULL);
	GXML_GNODE_GET_CLASS (self)->set_value (self, value);
}


static void gxml_gnode_real_set_value (GXmlGNode* base, const gchar* value) {
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	self = base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		return;
	}
	_tmp1_ = self->_node;
	_tmp2_ = value;
	xmlNodeSetContent (_tmp1_, (xmlChar*) _tmp2_);
	g_object_notify ((GObject *) self, "value");
}


static GXmlDomNodeNodeType gxml_gnode_real_get_node_type (GXmlDomNode* base) {
	GXmlDomNodeNodeType result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlElementType _tmp2_ = 0;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = GXML_DOM_NODE_NODE_TYPE_INVALID;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = _tmp1_->type;
	switch (_tmp2_) {
		case XML_ELEMENT_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_ELEMENT_NODE;
			return result;
		}
		case XML_ATTRIBUTE_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_ATTRIBUTE_NODE;
			return result;
		}
		case XML_TEXT_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_TEXT_NODE;
			return result;
		}
		case XML_CDATA_SECTION_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_CDATA_SECTION_NODE;
			return result;
		}
		case XML_ENTITY_REF_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_ENTITY_REFERENCE_NODE;
			return result;
		}
		case XML_ENTITY_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_ENTITY_NODE;
			return result;
		}
		case XML_PI_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_PROCESSING_INSTRUCTION_NODE;
			return result;
		}
		case XML_COMMENT_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_COMMENT_NODE;
			return result;
		}
		case XML_DOCUMENT_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_DOCUMENT_NODE;
			return result;
		}
		case XML_DOCUMENT_TYPE_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_DOCUMENT_TYPE_NODE;
			return result;
		}
		case XML_DOCUMENT_FRAG_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_DOCUMENT_FRAGMENT_NODE;
			return result;
		}
		case XML_NOTATION_NODE:
		{
			result = GXML_DOM_NODE_NODE_TYPE_NOTATION_NODE;
			return result;
		}
		default:
		break;
	}
	result = GXML_DOM_NODE_NODE_TYPE_INVALID;
	return result;
}


static gchar* gxml_gnode_real_get_node_name (GXmlDomNode* base) {
	gchar* result;
	GXmlGNode* self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_name (self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static const gchar* gxml_gnode_real_get_base_uri (GXmlDomNode* base) {
	const gchar* result;
	GXmlGNode* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_base_uri;
	result = _tmp0_;
	return result;
}


static GXmlDomDocument* gxml_gnode_real_get_owner_document (GXmlDomNode* base) {
	GXmlDomDocument* result;
	GXmlGNode* self;
	GXmlGDocument* _tmp0_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_doc;
	result = (GXmlDomDocument*) _tmp0_;
	return result;
}


static void gxml_gnode_real_set_owner_document (GXmlDomNode* base, GXmlDomDocument* value) {
	GXmlGNode* self;
	GXmlDomDocument* _tmp0_ = NULL;
	GXmlGDocument* _tmp1_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = value;
	_tmp1_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp0_, GXML_TYPE_GDOCUMENT) ? ((GXmlGDocument*) _tmp0_) : NULL);
	_g_object_unref0 (self->_doc);
	self->_doc = _tmp1_;
	g_object_notify ((GObject *) self, "owner-document");
}


static GXmlDomNode* gxml_gnode_real_get_parent_node (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGNode* self;
	GXmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GXmlDomNode* _tmp2_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_parent (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp1_) : NULL;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (_tmp1_);
	}
	result = _tmp2_;
	return result;
}


static GXmlDomElement* gxml_gnode_real_get_parent_element (GXmlDomNode* base) {
	GXmlDomElement* result;
	GXmlGNode* self;
	GXmlDomElement* nullnode = NULL;
	GXmlNode* _tmp0_ = NULL;
	GXmlNode* _tmp1_ = NULL;
	GXmlNode* _tmp2_ = NULL;
	gboolean _tmp3_ = FALSE;
	self = (GXmlGNode*) base;
	nullnode = NULL;
	_tmp0_ = gxml_gnode_get_parent (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp2_, GXML_TYPE_DOM_ELEMENT);
	_g_object_unref0 (_tmp2_);
	if (_tmp3_) {
		GXmlNode* _tmp4_ = NULL;
		GXmlNode* _tmp5_ = NULL;
		GXmlDomElement* _tmp6_ = NULL;
		_tmp4_ = gxml_gnode_get_parent (self);
		_tmp5_ = _tmp4_;
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp5_, GXML_TYPE_DOM_ELEMENT) ? ((GXmlDomElement*) _tmp5_) : NULL;
		if (_tmp6_ == NULL) {
			_g_object_unref0 (_tmp5_);
		}
		result = _tmp6_;
		_g_object_unref0 (nullnode);
		return result;
	}
	result = nullnode;
	return result;
}


static GXmlDomNodeList* gxml_gnode_real_get_child_nodes (GXmlDomNode* base) {
	GXmlDomNodeList* result;
	GXmlGNode* self;
	GeeBidirList* _tmp0_ = NULL;
	GeeBidirList* _tmp1_ = NULL;
	GXmlDomNodeList* _tmp2_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_children_nodes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp1_, GXML_TYPE_DOM_NODE_LIST) ? ((GXmlDomNodeList*) _tmp1_) : NULL;
	if (_tmp2_ == NULL) {
		_g_object_unref0 (_tmp1_);
	}
	result = _tmp2_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_get_first_child (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGNode* self;
	GeeBidirList* _tmp0_ = NULL;
	GeeBidirList* _tmp1_ = NULL;
	GeeBidirList* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomNode* _tmp6_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_children_nodes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_first ((GeeList*) _tmp2_);
	_tmp4_ = (GXmlNode*) _tmp3_;
	_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp4_) : NULL;
	if (_tmp5_ == NULL) {
		_g_object_unref0 (_tmp4_);
	}
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp2_);
	result = _tmp6_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_get_last_child (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGNode* self;
	GeeBidirList* _tmp0_ = NULL;
	GeeBidirList* _tmp1_ = NULL;
	GeeBidirList* _tmp2_ = NULL;
	gpointer _tmp3_ = NULL;
	GXmlNode* _tmp4_ = NULL;
	GXmlDomNode* _tmp5_ = NULL;
	GXmlDomNode* _tmp6_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_children_nodes (self);
	_tmp1_ = _tmp0_;
	_tmp2_ = _tmp1_;
	_tmp3_ = gee_list_last ((GeeList*) _tmp2_);
	_tmp4_ = (GXmlNode*) _tmp3_;
	_tmp5_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp4_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp4_) : NULL;
	if (_tmp5_ == NULL) {
		_g_object_unref0 (_tmp4_);
	}
	_tmp6_ = _tmp5_;
	_g_object_unref0 (_tmp2_);
	result = _tmp6_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_get_previous_sibling (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	GXmlGDocument* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	xmlNode* _tmp5_ = NULL;
	GXmlNode* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = _tmp1_->prev;
	if (_tmp2_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp3_ = self->_doc;
	_tmp4_ = self->_node;
	_tmp5_ = _tmp4_->prev;
	_tmp6_ = gxml_gnode_to_gnode (_tmp3_, _tmp5_);
	_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp6_) : NULL;
	if (_tmp7_ == NULL) {
		_g_object_unref0 (_tmp6_);
	}
	result = _tmp7_;
	return result;
}


static GXmlDomNode* gxml_gnode_real_get_next_sibling (GXmlDomNode* base) {
	GXmlDomNode* result;
	GXmlGNode* self;
	xmlNode* _tmp0_ = NULL;
	xmlNode* _tmp1_ = NULL;
	xmlNode* _tmp2_ = NULL;
	GXmlGDocument* _tmp3_ = NULL;
	xmlNode* _tmp4_ = NULL;
	xmlNode* _tmp5_ = NULL;
	GXmlNode* _tmp6_ = NULL;
	GXmlDomNode* _tmp7_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = self->_node;
	if (_tmp0_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp1_ = self->_node;
	_tmp2_ = _tmp1_->next;
	if (_tmp2_ == NULL) {
		result = NULL;
		return result;
	}
	_tmp3_ = self->_doc;
	_tmp4_ = self->_node;
	_tmp5_ = _tmp4_->next;
	_tmp6_ = gxml_gnode_to_gnode (_tmp3_, _tmp5_);
	_tmp7_ = G_TYPE_CHECK_INSTANCE_TYPE (_tmp6_, GXML_TYPE_DOM_NODE) ? ((GXmlDomNode*) _tmp6_) : NULL;
	if (_tmp7_ == NULL) {
		_g_object_unref0 (_tmp6_);
	}
	result = _tmp7_;
	return result;
}


static gchar* gxml_gnode_real_get_node_value (GXmlDomNode* base) {
	gchar* result;
	GXmlGNode* self;
	gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = gxml_gnode_get_value (self);
	_tmp1_ = _tmp0_;
	result = _tmp1_;
	return result;
}


static void gxml_gnode_real_set_node_value (GXmlDomNode* base, const gchar* value) {
	GXmlGNode* self;
	const gchar* _tmp0_ = NULL;
	self = (GXmlGNode*) base;
	_tmp0_ = value;
	gxml_gnode_set_value (self, _tmp0_);
	g_object_notify ((GObject *) self, "node-value");
}


static gchar* gxml_gnode_real_get_text_content (GXmlDomNode* base) {
	gchar* result;
	GXmlGNode* self;
	gchar* t = NULL;
	gboolean _tmp6_ = FALSE;
	self = (GXmlGNode*) base;
	t = NULL;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_TEXT)) {
		gchar* _tmp0_ = NULL;
		gchar* _tmp1_ = NULL;
		_tmp0_ = gxml_gnode_get_value (self);
		_tmp1_ = _tmp0_;
		result = _tmp1_;
		_g_free0 (t);
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_PROCESSING_INSTRUCTION)) {
		gchar* _tmp2_ = NULL;
		gchar* _tmp3_ = NULL;
		_tmp2_ = gxml_gnode_get_value (self);
		_tmp3_ = _tmp2_;
		result = _tmp3_;
		_g_free0 (t);
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_COMMENT)) {
		gchar* _tmp4_ = NULL;
		gchar* _tmp5_ = NULL;
		_tmp4_ = gxml_gnode_get_value (self);
		_tmp5_ = _tmp4_;
		result = _tmp5_;
		_g_free0 (t);
		return result;
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT)) {
		_tmp6_ = TRUE;
	} else {
		_tmp6_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_ELEMENT);
	}
	if (_tmp6_) {
		{
			GeeBidirList* _n_list = NULL;
			GeeBidirList* _tmp7_ = NULL;
			GeeBidirList* _tmp8_ = NULL;
			gint _n_size = 0;
			GeeBidirList* _tmp9_ = NULL;
			gint _tmp10_ = 0;
			gint _tmp11_ = 0;
			gint _n_index = 0;
			_tmp7_ = gxml_gnode_get_children_nodes (self);
			_tmp8_ = _tmp7_;
			_n_list = _tmp8_;
			_tmp9_ = _n_list;
			_tmp10_ = gee_collection_get_size ((GeeCollection*) _tmp9_);
			_tmp11_ = _tmp10_;
			_n_size = _tmp11_;
			_n_index = -1;
			while (TRUE) {
				gint _tmp12_ = 0;
				gint _tmp13_ = 0;
				gint _tmp14_ = 0;
				GXmlNode* n = NULL;
				GeeBidirList* _tmp15_ = NULL;
				gint _tmp16_ = 0;
				gpointer _tmp17_ = NULL;
				GXmlNode* _tmp18_ = NULL;
				_tmp12_ = _n_index;
				_n_index = _tmp12_ + 1;
				_tmp13_ = _n_index;
				_tmp14_ = _n_size;
				if (!(_tmp13_ < _tmp14_)) {
					break;
				}
				_tmp15_ = _n_list;
				_tmp16_ = _n_index;
				_tmp17_ = gee_list_get ((GeeList*) _tmp15_, _tmp16_);
				n = (GXmlNode*) _tmp17_;
				_tmp18_ = n;
				if (G_TYPE_CHECK_INSTANCE_TYPE (_tmp18_, GXML_TYPE_TEXT)) {
					const gchar* _tmp19_ = NULL;
					_tmp19_ = t;
					if (_tmp19_ == NULL) {
						GXmlNode* _tmp20_ = NULL;
						gchar* _tmp21_ = NULL;
						gchar* _tmp22_ = NULL;
						_tmp20_ = n;
						_tmp21_ = gxml_node_get_value (_tmp20_);
						_tmp22_ = _tmp21_;
						_g_free0 (t);
						t = _tmp22_;
					} else {
						const gchar* _tmp23_ = NULL;
						GXmlNode* _tmp24_ = NULL;
						gchar* _tmp25_ = NULL;
						gchar* _tmp26_ = NULL;
						gchar* _tmp27_ = NULL;
						gchar* _tmp28_ = NULL;
						_tmp23_ = t;
						_tmp24_ = n;
						_tmp25_ = gxml_node_get_value (_tmp24_);
						_tmp26_ = _tmp25_;
						_tmp27_ = _tmp26_;
						_tmp28_ = g_strconcat (_tmp23_, _tmp27_, NULL);
						_g_free0 (t);
						t = _tmp28_;
						_g_free0 (_tmp27_);
					}
				}
				_g_object_unref0 (n);
			}
			_g_object_unref0 (_n_list);
		}
	}
	result = t;
	return result;
}


static void gxml_gnode_real_set_text_content (GXmlDomNode* base, const gchar* value) {
	GXmlGNode* self;
	gboolean _tmp0_ = FALSE;
	gboolean _tmp11_ = FALSE;
	gboolean _tmp12_ = FALSE;
	const gchar* _tmp13_ = NULL;
	self = (GXmlGNode*) base;
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_DOCUMENT)) {
		_tmp0_ = TRUE;
	} else {
		_tmp0_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_ELEMENT);
	}
	if (_tmp0_) {
		GXmlNode* t = NULL;
		GXmlDocument* _tmp1_ = NULL;
		GXmlDocument* _tmp2_ = NULL;
		const gchar* _tmp3_ = NULL;
		GXmlNode* _tmp4_ = NULL;
		GXmlDocument* _tmp5_ = NULL;
		GXmlDocument* _tmp6_ = NULL;
		GeeBidirList* _tmp7_ = NULL;
		GeeBidirList* _tmp8_ = NULL;
		GeeBidirList* _tmp9_ = NULL;
		GXmlNode* _tmp10_ = NULL;
		_tmp1_ = gxml_gnode_get_document (self);
		_tmp2_ = _tmp1_;
		_tmp3_ = value;
		_tmp4_ = gxml_document_create_text (_tmp2_, _tmp3_);
		t = _tmp4_;
		_tmp5_ = gxml_gnode_get_document (self);
		_tmp6_ = _tmp5_;
		_tmp7_ = gxml_node_get_children_nodes ((GXmlNode*) _tmp6_);
		_tmp8_ = _tmp7_;
		_tmp9_ = _tmp8_;
		_tmp10_ = t;
		gee_collection_add ((GeeCollection*) _tmp9_, _tmp10_);
		_g_object_unref0 (_tmp9_);
		_g_object_unref0 (t);
	}
	if (G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_TEXT)) {
		_tmp12_ = TRUE;
	} else {
		_tmp12_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_COMMENT);
	}
	if (_tmp12_) {
		_tmp11_ = TRUE;
	} else {
		_tmp11_ = G_TYPE_CHECK_INSTANCE_TYPE (self, GXML_TYPE_PROCESSING_INSTRUCTION);
	}
	if (!_tmp11_) {
		return;
	}
	_tmp13_ = value;
	gxml_gnode_set_value (self, _tmp13_);
	g_object_notify ((GObject *) self, "text-content");
}


static GObject * gxml_gnode_constructor (GType type, guint n_construct_properties, GObjectConstructParam * construct_properties) {
	GObject * obj;
	GObjectClass * parent_class;
	GXmlGNode * self;
	parent_class = G_OBJECT_CLASS (gxml_gnode_parent_class);
	obj = parent_class->constructor (type, n_construct_properties, construct_properties);
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GNODE, GXmlGNode);
	gxml_init_init ();
	return obj;
}


static void gxml_gnode_class_init (GXmlGNodeClass * klass) {
	gxml_gnode_parent_class = g_type_class_peek_parent (klass);
	((GXmlGNodeClass *) klass)->set_namespace = (gboolean (*)(GXmlGNode*, const gchar*, const gchar*)) gxml_gnode_real_set_namespace;
	((GXmlGNodeClass *) klass)->to_string = (gchar* (*)(GXmlGNode*)) gxml_gnode_real_to_string;
	GXML_GNODE_CLASS (klass)->get_attrs = gxml_gnode_real_get_attrs;
	GXML_GNODE_CLASS (klass)->get_children_nodes = gxml_gnode_real_get_children_nodes;
	GXML_GNODE_CLASS (klass)->get_namespaces = gxml_gnode_real_get_namespaces;
	GXML_GNODE_CLASS (klass)->get_document = gxml_gnode_real_get_document;
	GXML_GNODE_CLASS (klass)->get_parent = gxml_gnode_real_get_parent;
	GXML_GNODE_CLASS (klass)->get_type_node = gxml_gnode_real_get_type_node;
	GXML_GNODE_CLASS (klass)->get_name = gxml_gnode_real_get_name;
	GXML_GNODE_CLASS (klass)->get_value = gxml_gnode_real_get_value;
	GXML_GNODE_CLASS (klass)->set_value = gxml_gnode_real_set_value;
	G_OBJECT_CLASS (klass)->get_property = _vala_gxml_gnode_get_property;
	G_OBJECT_CLASS (klass)->set_property = _vala_gxml_gnode_set_property;
	G_OBJECT_CLASS (klass)->constructor = gxml_gnode_constructor;
	G_OBJECT_CLASS (klass)->finalize = gxml_gnode_finalize;
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_ATTRS, g_param_spec_object ("attrs", "attrs", "attrs", GEE_TYPE_MAP, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_CHILDREN_NODES, g_param_spec_object ("children-nodes", "children-nodes", "children-nodes", GEE_TYPE_BIDIR_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NAMESPACES, g_param_spec_object ("namespaces", "namespaces", "namespaces", GEE_TYPE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_DOCUMENT, g_param_spec_object ("document", "document", "document", GXML_TYPE_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_PARENT, g_param_spec_object ("parent", "parent", "parent", GXML_TYPE_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_TYPE_NODE, g_param_spec_enum ("type-node", "type-node", "type-node", GXML_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NAME, g_param_spec_string ("name", "name", "name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_VALUE, g_param_spec_string ("value", "value", "value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NODE_TYPE, g_param_spec_enum ("node-type", "node-type", "node-type", GXML_DOM_NODE_TYPE_NODE_TYPE, 0, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NODE_NAME, g_param_spec_string ("node-name", "node-name", "node-name", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_BASE_URI, g_param_spec_string ("base-uri", "base-uri", "base-uri", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_OWNER_DOCUMENT, g_param_spec_object ("owner-document", "owner-document", "owner-document", GXML_TYPE_DOM_DOCUMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE | G_PARAM_CONSTRUCT));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_PARENT_NODE, g_param_spec_object ("parent-node", "parent-node", "parent-node", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_PARENT_ELEMENT, g_param_spec_object ("parent-element", "parent-element", "parent-element", GXML_TYPE_DOM_ELEMENT, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_CHILD_NODES, g_param_spec_object ("child-nodes", "child-nodes", "child-nodes", GXML_TYPE_DOM_NODE_LIST, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_FIRST_CHILD, g_param_spec_object ("first-child", "first-child", "first-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_LAST_CHILD, g_param_spec_object ("last-child", "last-child", "last-child", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_PREVIOUS_SIBLING, g_param_spec_object ("previous-sibling", "previous-sibling", "previous-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NEXT_SIBLING, g_param_spec_object ("next-sibling", "next-sibling", "next-sibling", GXML_TYPE_DOM_NODE, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_NODE_VALUE, g_param_spec_string ("node-value", "node-value", "node-value", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
	g_object_class_install_property (G_OBJECT_CLASS (klass), GXML_GNODE_TEXT_CONTENT, g_param_spec_string ("text-content", "text-content", "text-content", NULL, G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB | G_PARAM_READABLE | G_PARAM_WRITABLE));
}


static void gxml_gnode_gxml_dom_event_target_interface_init (GXmlDomEventTargetIface * iface) {
	gxml_gnode_gxml_dom_event_target_parent_iface = g_type_interface_peek_parent (iface);
	iface->add_event_listener = (void (*)(GXmlDomEventTarget*, const gchar*, GXmlDomEventListener*, gboolean)) gxml_gnode_real_add_event_listener;
	iface->remove_event_listener = (void (*)(GXmlDomEventTarget*, const gchar*, GXmlDomEventListener*, gboolean)) gxml_gnode_real_remove_event_listener;
	iface->dispatch_event = (gboolean (*)(GXmlDomEventTarget*, GXmlDomEvent*, GError**)) gxml_gnode_real_dispatch_event;
}


static void gxml_gnode_gxml_dom_node_interface_init (GXmlDomNodeIface * iface) {
	gxml_gnode_gxml_dom_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->has_child_nodes = (gboolean (*)(GXmlDomNode*)) gxml_gnode_real_has_child_nodes;
	iface->normalize = (void (*)(GXmlDomNode*)) gxml_gnode_real_normalize;
	iface->clone_node = (GXmlDomNode* (*)(GXmlDomNode*, gboolean, GError**)) gxml_gnode_real_clone_node;
	iface->is_equal_node = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gnode_real_is_equal_node;
	iface->compare_document_position = (GXmlDomNodeDocumentPosition (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gnode_real_compare_document_position;
	iface->contains = (gboolean (*)(GXmlDomNode*, GXmlDomNode*)) gxml_gnode_real_contains;
	iface->lookup_prefix = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_gnode_real_lookup_prefix;
	iface->lookup_namespace_uri = (gchar* (*)(GXmlDomNode*, const gchar*)) gxml_gnode_real_lookup_namespace_uri;
	iface->is_default_namespace = (gboolean (*)(GXmlDomNode*, const gchar*)) gxml_gnode_real_is_default_namespace;
	iface->insert_before = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gnode_real_insert_before;
	iface->append_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gnode_real_append_child;
	iface->replace_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gnode_real_replace_child;
	iface->remove_child = (GXmlDomNode* (*)(GXmlDomNode*, GXmlDomNode*, GError**)) gxml_gnode_real_remove_child;
	iface->get_node_type = gxml_gnode_real_get_node_type;
	iface->get_node_name = gxml_gnode_real_get_node_name;
	iface->get_base_uri = gxml_gnode_real_get_base_uri;
	iface->get_owner_document = gxml_gnode_real_get_owner_document;
	iface->set_owner_document = gxml_gnode_real_set_owner_document;
	iface->get_parent_node = gxml_gnode_real_get_parent_node;
	iface->get_parent_element = gxml_gnode_real_get_parent_element;
	iface->get_child_nodes = gxml_gnode_real_get_child_nodes;
	iface->get_first_child = gxml_gnode_real_get_first_child;
	iface->get_last_child = gxml_gnode_real_get_last_child;
	iface->get_previous_sibling = gxml_gnode_real_get_previous_sibling;
	iface->get_next_sibling = gxml_gnode_real_get_next_sibling;
	iface->get_node_value = gxml_gnode_real_get_node_value;
	iface->set_node_value = gxml_gnode_real_set_node_value;
	iface->get_text_content = gxml_gnode_real_get_text_content;
	iface->set_text_content = gxml_gnode_real_set_text_content;
}


static void gxml_gnode_gxml_node_interface_init (GXmlNodeIface * iface) {
	gxml_gnode_gxml_node_parent_iface = g_type_interface_peek_parent (iface);
	iface->set_namespace = (gboolean (*)(GXmlNode*, const gchar*, const gchar*)) gxml_gnode_set_namespace;
	iface->to_string = (gchar* (*)(GXmlNode*)) gxml_gnode_to_string;
	iface->get_attrs = (GeeMap* (*) (GXmlNode *)) gxml_gnode_get_attrs;
	iface->get_children_nodes = (GeeBidirList* (*) (GXmlNode *)) gxml_gnode_get_children_nodes;
	iface->get_namespaces = (GeeList* (*) (GXmlNode *)) gxml_gnode_get_namespaces;
	iface->get_document = (GXmlDocument* (*) (GXmlNode *)) gxml_gnode_get_document;
	iface->get_parent = (GXmlNode* (*) (GXmlNode *)) gxml_gnode_get_parent;
	iface->get_type_node = (GXmlNodeType (*) (GXmlNode *)) gxml_gnode_get_type_node;
	iface->get_name = (gchar* (*) (GXmlNode *)) gxml_gnode_get_name;
	iface->get_value = (gchar* (*) (GXmlNode *)) gxml_gnode_get_value;
	iface->set_value = (void (*) (GXmlNode *, const gchar*)) gxml_gnode_set_value;
}


static void gxml_gnode_instance_init (GXmlGNode * self) {
	self->_base_uri = NULL;
}


static void gxml_gnode_finalize (GObject* obj) {
	GXmlGNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, GXML_TYPE_GNODE, GXmlGNode);
	_g_object_unref0 (self->_doc);
	_g_free0 (self->_base_uri);
	G_OBJECT_CLASS (gxml_gnode_parent_class)->finalize (obj);
}


/**
 * Base interface providing basic functionalities to all GXml interfaces.
 */
GType gxml_gnode_get_type (void) {
	static volatile gsize gxml_gnode_type_id__volatile = 0;
	if (g_once_init_enter (&gxml_gnode_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (GXmlGNodeClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) gxml_gnode_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (GXmlGNode), 0, (GInstanceInitFunc) gxml_gnode_instance_init, NULL };
		static const GInterfaceInfo gxml_dom_event_target_info = { (GInterfaceInitFunc) gxml_gnode_gxml_dom_event_target_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_dom_node_info = { (GInterfaceInitFunc) gxml_gnode_gxml_dom_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		static const GInterfaceInfo gxml_node_info = { (GInterfaceInitFunc) gxml_gnode_gxml_node_interface_init, (GInterfaceFinalizeFunc) NULL, NULL};
		GType gxml_gnode_type_id;
		gxml_gnode_type_id = g_type_register_static (G_TYPE_OBJECT, "GXmlGNode", &g_define_type_info, G_TYPE_FLAG_ABSTRACT);
		g_type_add_interface_static (gxml_gnode_type_id, GXML_TYPE_DOM_EVENT_TARGET, &gxml_dom_event_target_info);
		g_type_add_interface_static (gxml_gnode_type_id, GXML_TYPE_DOM_NODE, &gxml_dom_node_info);
		g_type_add_interface_static (gxml_gnode_type_id, GXML_TYPE_NODE, &gxml_node_info);
		g_once_init_leave (&gxml_gnode_type_id__volatile, gxml_gnode_type_id);
	}
	return gxml_gnode_type_id__volatile;
}


static void _vala_gxml_gnode_get_property (GObject * object, guint property_id, GValue * value, GParamSpec * pspec) {
	GXmlGNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GNODE, GXmlGNode);
	switch (property_id) {
		case GXML_GNODE_ATTRS:
		g_value_take_object (value, gxml_gnode_get_attrs (self));
		break;
		case GXML_GNODE_CHILDREN_NODES:
		g_value_take_object (value, gxml_gnode_get_children_nodes (self));
		break;
		case GXML_GNODE_NAMESPACES:
		g_value_take_object (value, gxml_gnode_get_namespaces (self));
		break;
		case GXML_GNODE_DOCUMENT:
		g_value_set_object (value, gxml_gnode_get_document (self));
		break;
		case GXML_GNODE_PARENT:
		g_value_take_object (value, gxml_gnode_get_parent (self));
		break;
		case GXML_GNODE_TYPE_NODE:
		g_value_set_enum (value, gxml_gnode_get_type_node (self));
		break;
		case GXML_GNODE_NAME:
		g_value_take_string (value, gxml_gnode_get_name (self));
		break;
		case GXML_GNODE_VALUE:
		g_value_take_string (value, gxml_gnode_get_value (self));
		break;
		case GXML_GNODE_NODE_TYPE:
		g_value_set_enum (value, gxml_dom_node_get_node_type ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_NODE_NAME:
		g_value_take_string (value, gxml_dom_node_get_node_name ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_BASE_URI:
		g_value_set_string (value, gxml_dom_node_get_base_uri ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_OWNER_DOCUMENT:
		g_value_set_object (value, gxml_dom_node_get_owner_document ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_PARENT_NODE:
		g_value_take_object (value, gxml_dom_node_get_parent_node ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_PARENT_ELEMENT:
		g_value_take_object (value, gxml_dom_node_get_parent_element ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_CHILD_NODES:
		g_value_take_object (value, gxml_dom_node_get_child_nodes ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_FIRST_CHILD:
		g_value_take_object (value, gxml_dom_node_get_first_child ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_LAST_CHILD:
		g_value_take_object (value, gxml_dom_node_get_last_child ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_PREVIOUS_SIBLING:
		g_value_take_object (value, gxml_dom_node_get_previous_sibling ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_NEXT_SIBLING:
		g_value_take_object (value, gxml_dom_node_get_next_sibling ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_NODE_VALUE:
		g_value_take_string (value, gxml_dom_node_get_node_value ((GXmlDomNode*) self));
		break;
		case GXML_GNODE_TEXT_CONTENT:
		g_value_take_string (value, gxml_dom_node_get_text_content ((GXmlDomNode*) self));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}


static void _vala_gxml_gnode_set_property (GObject * object, guint property_id, const GValue * value, GParamSpec * pspec) {
	GXmlGNode * self;
	self = G_TYPE_CHECK_INSTANCE_CAST (object, GXML_TYPE_GNODE, GXmlGNode);
	switch (property_id) {
		case GXML_GNODE_VALUE:
		gxml_gnode_set_value (self, g_value_get_string (value));
		break;
		case GXML_GNODE_OWNER_DOCUMENT:
		gxml_dom_node_set_owner_document ((GXmlDomNode*) self, g_value_get_object (value));
		break;
		case GXML_GNODE_NODE_VALUE:
		gxml_dom_node_set_node_value ((GXmlDomNode*) self, g_value_get_string (value));
		break;
		case GXML_GNODE_TEXT_CONTENT:
		gxml_dom_node_set_text_content ((GXmlDomNode*) self, g_value_get_string (value));
		break;
		default:
		G_OBJECT_WARN_INVALID_PROPERTY_ID (object, property_id, pspec);
		break;
	}
}



